@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -83,7 +83,6 @@
 #include <Qt3DAnimation/qanimationcliploader.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -98,6 +97,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -150,21 +154,22 @@ extern SbkConverter **SbkPySide6_Qt3DAnimationTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DANIMATION_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX       = 0, // QList<Qt3DCore::QAttribute* >
-    SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                   = 1, // QList<QObject* >
-    SBK_QT3DANIMATION_QLIST_QBYTEARRAY_IDX                   = 2, // QList<QByteArray >
-    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QANIMATIONGROUPPTR_IDX = 3, // QList<Qt3DAnimation::QAnimationGroup* >
-    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX = 4, // QList<Qt3DAnimation::QAbstractAnimation* >
-    SBK_QT3DANIMATION_QLIST_QT3DCORE_QNODEPTR_IDX            = 5, // QList<Qt3DCore::QNode* >
-    SBK_QT3DANIMATION_QLIST_QT3DCORE_QENTITYPTR_IDX          = 6, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTCHANNELMAPPINGPTR_IDX = 7, // QList<Qt3DAnimation::QAbstractChannelMapping* >
-    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QMORPHTARGETPTR_IDX = 8, // QList<Qt3DAnimation::QMorphTarget* >
-    SBK_QT3DANIMATION_QLIST_FLOAT_IDX                        = 9, // QList<float >
-    SBK_QT3DANIMATION_QLIST_QT3DCORE_QTRANSFORMPTR_IDX       = 10, // QList<Qt3DCore::QTransform* >
-    SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                     = 11, // QList<QVariant >
-    SBK_QT3DANIMATION_QLIST_QSTRING_IDX                      = 12, // QList<QString >
-    SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX              = 13, // QMap<QString,QVariant >
-    SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                   = 14
+    SBK_QT3DANIMATION_QLIST_INT_IDX                          = 0, // QList<int >
+    SBK_QT3DANIMATION_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX       = 1, // QList<Qt3DCore::QAttribute* >
+    SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                   = 2, // QList<QObject* >
+    SBK_QT3DANIMATION_QLIST_QBYTEARRAY_IDX                   = 3, // QList<QByteArray >
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QANIMATIONGROUPPTR_IDX = 4, // QList<Qt3DAnimation::QAnimationGroup* >
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX = 5, // QList<Qt3DAnimation::QAbstractAnimation* >
+    SBK_QT3DANIMATION_QLIST_QT3DCORE_QNODEPTR_IDX            = 6, // QList<Qt3DCore::QNode* >
+    SBK_QT3DANIMATION_QLIST_QT3DCORE_QENTITYPTR_IDX          = 7, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTCHANNELMAPPINGPTR_IDX = 8, // QList<Qt3DAnimation::QAbstractChannelMapping* >
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QMORPHTARGETPTR_IDX = 9, // QList<Qt3DAnimation::QMorphTarget* >
+    SBK_QT3DANIMATION_QLIST_FLOAT_IDX                        = 10, // QList<float >
+    SBK_QT3DANIMATION_QLIST_QT3DCORE_QTRANSFORMPTR_IDX       = 11, // QList<Qt3DCore::QTransform* >
+    SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                     = 12, // QList<QVariant >
+    SBK_QT3DANIMATION_QLIST_QSTRING_IDX                      = 13, // QList<QString >
+    SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX              = 14, // QMap<QString,QVariant >
+    SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                   = 15
 };
 // Macros for type check
 
