@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -99,7 +99,6 @@
 #include <Qt3DExtras/qspheremesh.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -114,6 +113,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -176,16 +180,17 @@ extern SbkConverter **SbkPySide6_Qt3DExtrasTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX          = 0, // QList<Qt3DCore::QAttribute* >
-    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 1, // QList<Qt3DRender::QParameter* >
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 2, // QList<Qt3DCore::QComponent* >
-    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QNODEPTR_IDX               = 3, // QList<Qt3DCore::QNode* >
-    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 4, // QList<Qt3DRender::QFilterKey* >
-    SBK_QT3DEXTRAS_QLIST_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX  = 5, // QList<Qt3DExtras::QSpriteSheetItem* >
-    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 6, // QList<QVariant >
-    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 7, // QList<QString >
-    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 8, // QMap<QString,QVariant >
-    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 9
+    SBK_QT3DEXTRAS_QLIST_INT_IDX                             = 0, // QList<int >
+    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX          = 1, // QList<Qt3DCore::QAttribute* >
+    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 2, // QList<Qt3DRender::QParameter* >
+    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 3, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DEXTRAS_QLIST_QT3DCORE_QNODEPTR_IDX               = 4, // QList<Qt3DCore::QNode* >
+    SBK_QT3DEXTRAS_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 5, // QList<Qt3DRender::QFilterKey* >
+    SBK_QT3DEXTRAS_QLIST_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX  = 6, // QList<Qt3DExtras::QSpriteSheetItem* >
+    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 7, // QList<QVariant >
+    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 8, // QList<QString >
+    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 9, // QMap<QString,QVariant >
+    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 10
 };
 // Macros for type check
 
