@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -75,7 +75,6 @@
 #include <Qt3DInput/qactioninput.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -90,6 +89,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -135,12 +139,12 @@ extern SbkConverter **SbkPySide6_Qt3DInputTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DINPUT_QLIST_QT3DCORE_QENTITYPTR_IDX              = 0, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DINPUT_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
-    SBK_QT3DINPUT_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
-    SBK_QT3DINPUT_QLIST_QT3DINPUT_QACTIONPTR_IDX             = 3, // QList<Qt3DInput::QAction* >
-    SBK_QT3DINPUT_QLIST_QT3DINPUT_QAXISPTR_IDX               = 4, // QList<Qt3DInput::QAxis* >
-    SBK_QT3DINPUT_QLIST_INT_IDX                              = 5, // QList<int >
+    SBK_QT3DINPUT_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QT3DINPUT_QLIST_QT3DCORE_QENTITYPTR_IDX              = 1, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DINPUT_QLIST_QOBJECTPTR_IDX                       = 2, // QList<QObject* >
+    SBK_QT3DINPUT_QLIST_QBYTEARRAY_IDX                       = 3, // QList<QByteArray >
+    SBK_QT3DINPUT_QLIST_QT3DINPUT_QACTIONPTR_IDX             = 4, // QList<Qt3DInput::QAction* >
+    SBK_QT3DINPUT_QLIST_QT3DINPUT_QAXISPTR_IDX               = 5, // QList<Qt3DInput::QAxis* >
     SBK_QT3DINPUT_QLIST_QT3DCORE_QNODEPTR_IDX                = 6, // QList<Qt3DCore::QNode* >
     SBK_QT3DINPUT_QLIST_QT3DINPUT_QABSTRACTAXISINPUTPTR_IDX  = 7, // QList<Qt3DInput::QAbstractAxisInput* >
     SBK_QT3DINPUT_QLIST_QT3DINPUT_QABSTRACTACTIONINPUTPTR_IDX = 8, // QList<Qt3DInput::QAbstractActionInput* >
