@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -73,7 +73,6 @@
 #include <QtBluetooth/qbluetoothservicediscoveryagent.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -88,6 +87,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -181,25 +185,27 @@ extern SbkConverter **SbkPySide6_QtBluetoothTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTICDATA_IDX   = 0, // QList<QLowEnergyCharacteristicData >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYSERVICEPTR_IDX           = 1, // QList<QLowEnergyService* >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTIC_IDX       = 2, // QList<QLowEnergyCharacteristic >
-    SBK_QTBLUETOOTH_QLIST_QOBJECTPTR_IDX                     = 3, // QList<QObject* >
-    SBK_QTBLUETOOTH_QLIST_QBYTEARRAY_IDX                     = 4, // QList<QByteArray >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 5, // QList<QBluetoothUuid >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 6, // QList<QLowEnergyDescriptorData >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 7, // QList<QLowEnergyDescriptor >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 8, // QList<QLowEnergyAdvertisingParameters::AddressInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 9, // QList<QBluetoothServiceInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 10, // QList<QBluetoothHostInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 11, // QList<QBluetoothAddress >
-    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 12, // QMultiHash<quint16,QByteArray >
-    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 13, // QList<quint16 >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 14, // QList<QBluetoothDeviceInfo >
-    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 15, // QList<QVariant >
-    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 16, // QList<QString >
-    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 17, // QMap<QString,QVariant >
-    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 18
+    SBK_QTBLUETOOTH_QLIST_INT_IDX                            = 0, // QList<int >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTICDATA_IDX   = 1, // QList<QLowEnergyCharacteristicData >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYSERVICEPTR_IDX           = 2, // QList<QLowEnergyService* >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTIC_IDX       = 3, // QList<QLowEnergyCharacteristic >
+    SBK_QTBLUETOOTH_QLIST_QOBJECTPTR_IDX                     = 4, // QList<QObject* >
+    SBK_QTBLUETOOTH_QLIST_QBYTEARRAY_IDX                     = 5, // QList<QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 6, // QList<QBluetoothUuid >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 7, // QList<QLowEnergyDescriptorData >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 8, // QList<QLowEnergyDescriptor >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 9, // QList<QLowEnergyAdvertisingParameters::AddressInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 10, // QList<QBluetoothServiceInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 11, // QList<QBluetoothHostInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 12, // QList<QBluetoothAddress >
+    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 13, // QMultiHash<quint16,QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 14, // QList<quint16 >
+    SBK_QTBLUETOOTH_QMULTIHASH_QBLUETOOTHUUID_QBYTEARRAY_IDX = 15, // QMultiHash<QBluetoothUuid,QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 16, // QList<QBluetoothDeviceInfo >
+    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 17, // QList<QVariant >
+    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 18, // QList<QString >
+    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 19, // QMap<QString,QVariant >
+    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 20
 };
 // Macros for type check
 
