@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -85,6 +85,7 @@
 #include <QtCharts/qstackedbarseries.h>
 #include <QtCharts/qhorizontalpercentbarseries.h>
 #include <QtCharts/qpiemodelmapper.h>
+#include <QtCharts/qxyseries.h>
 #include <QtCharts/qpieseries.h>
 #include <QtCharts/qabstractseries.h>
 #include <QtCharts/qabstractaxis.h>
@@ -106,7 +107,6 @@
 #include <QtCharts/qhorizontalbarseries.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -121,6 +121,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -193,8 +198,9 @@ enum : int {
     SBK_QVALUEAXIS_IDX                                       = 65,
     SBK_QXYLEGENDMARKER_IDX                                  = 67,
     SBK_QXYMODELMAPPER_IDX                                   = 68,
+    SBK_QXYSERIES_POINTCONFIGURATION_IDX                     = 70,
     SBK_QXYSERIES_IDX                                        = 69,
-    SBK_QtCharts_IDX_COUNT                                   = 70
+    SBK_QtCharts_IDX_COUNT                                   = 71
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtChartsTypes;
@@ -207,26 +213,28 @@ extern SbkConverter **SbkPySide6_QtChartsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 0, // QList<QObject* >
-    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 1, // QList<QByteArray >
-    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 2, // QList<QAction* >
-    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 3, // QList<QLegendMarker* >
-    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 4, // QList<QGraphicsItem* >
-    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 5, // QList<QRectF >
-    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 6, // QList<QAbstractAxis* >
-    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 7, // QList<QAbstractSeries* >
-    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 8, // QList<qreal >
-    SBK_QTCHARTS_QLIST_INT_IDX                               = 9, // QList<int >
+    SBK_QTCHARTS_QLIST_INT_IDX                               = 0, // QList<int >
+    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 1, // QList<QObject* >
+    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 2, // QList<QByteArray >
+    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 3, // QList<QAction* >
+    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 4, // QList<QLegendMarker* >
+    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 5, // QList<QGraphicsItem* >
+    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 6, // QList<QRectF >
+    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 7, // QList<QAbstractAxis* >
+    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 8, // QList<QAbstractSeries* >
+    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 9, // QList<qreal >
     SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF >
     SBK_QTCHARTS_QPAIR_QREAL_QREAL_IDX                       = 11, // QPair<qreal,qreal >
-    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 12, // QList<QPieSlice* >
-    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 13, // QList<QCandlestickSet* >
-    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 14, // QList<QBoxSet* >
-    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 15, // QList<QBarSet* >
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 16, // QList<QVariant >
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 17, // QList<QString >
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 18, // QMap<QString,QVariant >
-    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 19
+    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant >
+    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 13, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant > >
+    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 14, // QList<QPieSlice* >
+    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 15, // QList<QCandlestickSet* >
+    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 16, // QList<QBoxSet* >
+    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 17, // QList<QBarSet* >
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 18, // QList<QVariant >
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 19, // QList<QString >
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 20, // QMap<QString,QVariant >
+    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 21
 };
 // Macros for type check
 
@@ -305,6 +313,7 @@ template<> inline PyTypeObject *SbkType< ::QValueAxis::TickType >() { return Sbk
 template<> inline PyTypeObject *SbkType< ::QValueAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QVALUEAXIS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QXYLegendMarker >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYLEGENDMARKER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QXYModelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYMODELMAPPER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QXYSeries::PointConfiguration >() { return SbkPySide6_QtChartsTypes[SBK_QXYSERIES_POINTCONFIGURATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QXYSeries >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtChartsTypes[SBK_QXYSERIES_IDX]); }
 QT_WARNING_POP
 
