@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -57,7 +57,6 @@
 #include <QtConcurrent/qtconcurrentreducekernel.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -72,6 +71,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -100,10 +104,11 @@ extern SbkConverter **SbkPySide6_QtConcurrentTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                      = 0, // QList<QVariant >
-    SBK_QTCONCURRENT_QLIST_QSTRING_IDX                       = 1, // QList<QString >
-    SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX               = 2, // QMap<QString,QVariant >
-    SBK_QtConcurrent_CONVERTERS_IDX_COUNT                    = 3
+    SBK_QTCONCURRENT_QLIST_INT_IDX                           = 0, // QList<int >
+    SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                      = 1, // QList<QVariant >
+    SBK_QTCONCURRENT_QLIST_QSTRING_IDX                       = 2, // QList<QString >
+    SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX               = 3, // QMap<QString,QVariant >
+    SBK_QtConcurrent_CONVERTERS_IDX_COUNT                    = 4
 };
 
 // typedef entries
