@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -132,6 +132,7 @@
 #include <QtGui/qoffscreensurface.h>
 #include <QtGui/qpixmap.h>
 #include <QtGui/qquaternion.h>
+#include <qtguihelper.h>
 #include <QtGui/qevent.h>
 #include <QTextBlock>
 #include <QtGui/qcolortransform.h>
@@ -148,7 +149,6 @@
 #include <QtGui/qpaintdevice.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -163,6 +163,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -242,7 +247,7 @@ enum : int {
     SBK_QFOCUSEVENT_IDX                                      = 91,
     SBK_QFONT_STYLEHINT_IDX                                  = 97,
     SBK_QFONT_STYLESTRATEGY_IDX                              = 98,
-    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 350,
+    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 352,
     SBK_QFONT_WEIGHT_IDX                                     = 99,
     SBK_QFONT_STYLE_IDX                                      = 96,
     SBK_QFONT_STRETCH_IDX                                    = 95,
@@ -444,7 +449,7 @@ enum : int {
     SBK_QTABLETEVENT_IDX                                     = 271,
     SBK_QTEXTBLOCK_IDX                                       = 272,
     SBK_QTEXTBLOCK_ITERATOR_IDX                              = 273,
-    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 351,
+    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 353,
     SBK_QTEXTBLOCKFORMAT_MARKERTYPE_IDX                      = 275,
     SBK_QTEXTBLOCKFORMAT_IDX                                 = 274,
     SBK_QTEXTBLOCKGROUP_IDX                                  = 276,
@@ -526,7 +531,8 @@ enum : int {
     SBK_QWINDOW_IDX                                          = 345,
     SBK_QWINDOWSTATECHANGEEVENT_IDX                          = 348,
     SBK_QtGuiQT_IDX                                          = 349,
-    SBK_QtGui_IDX_COUNT                                      = 352
+    SBK_QTGUIHELPER_QOVERRIDECURSORGUARD_IDX                 = 351,
+    SBK_QtGui_IDX_COUNT                                      = 354
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtGuiTypes;
@@ -540,55 +546,59 @@ extern SbkConverter **SbkPySide6_QtGuiTypeConverters;
 // Converter indices
 enum : int {
     SBK_WID_IDX                                              = 0,
-    SBK_QTGUI_QLIST_QREAL_IDX                                = 1, // QList<qreal >
-    SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX                      = 2, // QList<QTextOption::Tab >
-    SBK_QTGUI_QLIST_QGLYPHRUN_IDX                            = 3, // QList<QGlyphRun >
-    SBK_QTGUI_QLIST_QTEXTLENGTH_IDX                          = 4, // QList<QTextLength >
-    SBK_QTGUI_QMAP_INT_QVARIANT_IDX                          = 5, // QMap<int,QVariant >
-    SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX              = 6, // QList<QTextLayout::FormatRange >
-    SBK_QTGUI_QPAIR_INT_INT_IDX                              = 7, // QPair<int,int >
-    SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX                     = 8, // QList<QStandardItem* >
-    SBK_QTGUI_QLIST_QPOINTF_IDX                              = 9, // QList<QPointF >
-    SBK_QTGUI_QLIST_QUINT32_IDX                              = 10, // QList<quint32 >
-    SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX          = 11, // QList<QFontDatabase::WritingSystem >
-    SBK_QTGUI_QLIST_QPOINT_IDX                               = 12, // QList<QPoint >
-    SBK_QTGUI_QLIST_QPOLYGONF_IDX                            = 13, // QList<QPolygonF >
-    SBK_QTGUI_QLIST_QPAGERANGES_RANGE_IDX                    = 14, // QList<QPageRanges::Range >
-    SBK_QTGUI_QLIST_FLOAT_IDX                                = 15, // QList<float >
-    SBK_QTGUI_QLIST_QSIZE_IDX                                = 16, // QList<QSize >
-    SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX                      = 17, // std::pair<qreal,QColor >
-    SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 18, // QList<std::pair< qreal,QColor > >
-    SBK_QTGUI_QLIST_INT_IDX                                  = 19, // QList<int >
-    SBK_QTGUI_QLIST_UINT16_T_IDX                             = 20, // QList<uint16_t >
-    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 21, // QList<QAccessibleInterface* >
-    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 22, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
-    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 23, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
-    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 24, // QList<unsigned int >
-    SBK_QTGUI_QLIST_QLINE_IDX                                = 25, // QList<QLine >
-    SBK_QTGUI_QLIST_QLINEF_IDX                               = 26, // QList<QLineF >
-    SBK_QTGUI_QLIST_QRECT_IDX                                = 27, // QList<QRect >
-    SBK_QTGUI_QLIST_QRECTF_IDX                               = 28, // QList<QRectF >
-    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 29, // QList<QKeySequence >
-    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 30, // QList<QObject* >
-    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 31, // QList<QByteArray >
-    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 32, // QList<QUndoStack* >
-    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 33, // QList<QTextFrame* >
-    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 34, // QList<QTextBlock >
-    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 35, // QList<QTextFormat >
-    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 36, // QList<QScreen* >
-    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 37, // QList<QOpenGLContext* >
-    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 38, // QSet<QByteArray >
-    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 39, // QList<const QInputDevice* >
-    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 40, // QList<QAction* >
-    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 41, // QList<QInputMethodEvent::Attribute >
-    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 42, // QList<QEventPoint >
-    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 43, // QList<QWindow* >
-    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 44, // QList<QPersistentModelIndex >
-    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 45, // QHash<int,QByteArray >
-    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 46, // QList<QVariant >
-    SBK_QTGUI_QLIST_QSTRING_IDX                              = 47, // QList<QString >
-    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 48, // QMap<QString,QVariant >
-    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 49
+    SBK_QTGUI_QLIST_INT_IDX                                  = 1, // QList<int >
+    SBK_QTGUI_QLIST_QVECTOR2D_IDX                            = 2, // QList<QVector2D >
+    SBK_QTGUI_QLIST_QVECTOR3D_IDX                            = 3, // QList<QVector3D >
+    SBK_QTGUI_QLIST_QVECTOR4D_IDX                            = 4, // QList<QVector4D >
+    SBK_QTGUI_QLIST_QREAL_IDX                                = 5, // QList<qreal >
+    SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX                      = 6, // QList<QTextOption::Tab >
+    SBK_QTGUI_QLIST_QGLYPHRUN_IDX                            = 7, // QList<QGlyphRun >
+    SBK_QTGUI_QLIST_QTEXTLENGTH_IDX                          = 8, // QList<QTextLength >
+    SBK_QTGUI_QMAP_INT_QVARIANT_IDX                          = 9, // QMap<int,QVariant >
+    SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX              = 10, // QList<QTextLayout::FormatRange >
+    SBK_QTGUI_QPAIR_INT_INT_IDX                              = 11, // QPair<int,int >
+    SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX                     = 12, // QList<QStandardItem* >
+    SBK_QTGUI_QLIST_QPOINTF_IDX                              = 13, // QList<QPointF >
+    SBK_QTGUI_QLIST_QUINT32_IDX                              = 14, // QList<quint32 >
+    SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX          = 15, // QList<QFontDatabase::WritingSystem >
+    SBK_QTGUI_QLIST_QPOINT_IDX                               = 16, // QList<QPoint >
+    SBK_QTGUI_QLIST_QPOLYGONF_IDX                            = 17, // QList<QPolygonF >
+    SBK_QTGUI_QLIST_QPAGERANGES_RANGE_IDX                    = 18, // QList<QPageRanges::Range >
+    SBK_QTGUI_QLIST_FLOAT_IDX                                = 19, // QList<float >
+    SBK_QTGUI_QLIST_QSIZE_IDX                                = 20, // QList<QSize >
+    SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX                      = 21, // std::pair<qreal,QColor >
+    SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 22, // QList<std::pair< qreal,QColor > >
+    SBK_QTGUI_QLIST_UINT16_T_IDX                             = 23, // QList<uint16_t >
+    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 24, // QList<QAccessibleInterface* >
+    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 25, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
+    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 26, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
+    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 27, // QList<unsigned int >
+    SBK_QTGUI_QLIST_QLINE_IDX                                = 28, // QList<QLine >
+    SBK_QTGUI_QLIST_QLINEF_IDX                               = 29, // QList<QLineF >
+    SBK_QTGUI_QLIST_QRECT_IDX                                = 30, // QList<QRect >
+    SBK_QTGUI_QLIST_QRECTF_IDX                               = 31, // QList<QRectF >
+    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 32, // QList<QKeySequence >
+    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 33, // QList<QObject* >
+    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 34, // QList<QByteArray >
+    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 35, // QList<QUndoStack* >
+    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 36, // QList<QTextFrame* >
+    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 37, // QList<QTextBlock >
+    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 38, // QList<QTextFormat >
+    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 39, // QList<QScreen* >
+    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 40, // QList<QOpenGLContext* >
+    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 41, // QSet<QByteArray >
+    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 42, // QList<const QInputDevice* >
+    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 43, // QList<QAction* >
+    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 44, // QList<QInputMethodEvent::Attribute >
+    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 45, // QList<QEventPoint >
+    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 46, // QList<QWindow* >
+    SBK_QTGUI_QLIST_QMODELINDEX_IDX                          = 47, // QList<QModelIndex >
+    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 48, // QList<QPersistentModelIndex >
+    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 49, // QHash<int,QByteArray >
+    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 50, // QList<QVariant >
+    SBK_QTGUI_QLIST_QSTRING_IDX                              = 51, // QList<QString >
+    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 52, // QMap<QString,QVariant >
+    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 53
 };
 // Macros for type check
 
@@ -947,6 +957,7 @@ template<> inline PyTypeObject *SbkType< ::QWindow::Visibility >() { return SbkP
 template<> inline PyTypeObject *SbkType< ::QWindow::AncestorMode >() { return SbkPySide6_QtGuiTypes[SBK_QWINDOW_ANCESTORMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QWindow >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWindowStateChangeEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QWINDOWSTATECHANGEEVENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QtGuiHelper::QOverrideCursorGuard >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QTGUIHELPER_QOVERRIDECURSORGUARD_IDX]); }
 QT_WARNING_POP
 
 } // namespace Shiboken
