@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -58,7 +58,6 @@
 #include <QtMultimediaWidgets/qgraphicsvideoitem.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -73,6 +72,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -91,11 +95,12 @@ extern SbkConverter **SbkPySide6_QtMultimediaWidgetsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QACTIONPTR_IDX             = 0, // QList<QAction* >
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX               = 1, // QList<QVariant >
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                = 2, // QList<QString >
-    SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX        = 3, // QMap<QString,QVariant >
-    SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT             = 4
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_INT_IDX                    = 0, // QList<int >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QACTIONPTR_IDX             = 1, // QList<QAction* >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX               = 2, // QList<QVariant >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                = 3, // QList<QString >
+    SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX        = 4, // QMap<QString,QVariant >
+    SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT             = 5
 };
 // Macros for type check
 
