@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -90,7 +90,6 @@
 #include <QtNetwork/qlocalserver.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -105,6 +104,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -165,68 +169,69 @@ enum : int {
     SBK_QNETWORKDATAGRAM_IDX                                 = 59,
     SBK_QNETWORKDISKCACHE_IDX                                = 60,
     SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 63,
+    SBK_QNETWORKINFORMATION_TRANSPORTMEDIUM_IDX              = 64,
     SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 62,
     SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 28,
     SBK_QNETWORKINFORMATION_IDX                              = 61,
-    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 65,
+    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 66,
     SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 29,
-    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 66,
-    SBK_QNETWORKINTERFACE_IDX                                = 64,
-    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 69,
-    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 68,
+    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 67,
+    SBK_QNETWORKINTERFACE_IDX                                = 65,
+    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 70,
+    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 69,
     SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 30,
-    SBK_QNETWORKPROXY_IDX                                    = 67,
-    SBK_QNETWORKPROXYFACTORY_IDX                             = 70,
-    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 72,
-    SBK_QNETWORKPROXYQUERY_IDX                               = 71,
-    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 74,
-    SBK_QNETWORKREPLY_IDX                                    = 73,
-    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 78,
-    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 76,
-    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 77,
-    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 79,
-    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 80,
-    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 81,
-    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 82,
-    SBK_QNETWORKREQUEST_IDX                                  = 75,
-    SBK_QOCSPRESPONSE_IDX                                    = 84,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 86,
-    SBK_QSSL_KEYTYPE_IDX                                     = 94,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 91,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 93,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 90,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 96,
-    SBK_QSSL_SSLOPTION_IDX                                   = 95,
+    SBK_QNETWORKPROXY_IDX                                    = 68,
+    SBK_QNETWORKPROXYFACTORY_IDX                             = 71,
+    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 73,
+    SBK_QNETWORKPROXYQUERY_IDX                               = 72,
+    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 75,
+    SBK_QNETWORKREPLY_IDX                                    = 74,
+    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 79,
+    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 77,
+    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 78,
+    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 80,
+    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 81,
+    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 82,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 83,
+    SBK_QNETWORKREQUEST_IDX                                  = 76,
+    SBK_QOCSPRESPONSE_IDX                                    = 85,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 87,
+    SBK_QSSL_KEYTYPE_IDX                                     = 95,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 92,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 94,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 91,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 97,
+    SBK_QSSL_SSLOPTION_IDX                                   = 96,
     SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
-    SBK_QSSL_ALERTLEVEL_IDX                                  = 88,
-    SBK_QSSL_ALERTTYPE_IDX                                   = 89,
-    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 92,
-    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 97,
-    SBK_QtNetworkQSSL_IDX                                    = 87,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 100,
-    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 99,
-    SBK_QSSLCERTIFICATE_IDX                                  = 98,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 101,
-    SBK_QSSLCIPHER_IDX                                       = 102,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 104,
-    SBK_QSSLCONFIGURATION_IDX                                = 103,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 106,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 105,
-    SBK_QSSLELLIPTICCURVE_IDX                                = 107,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 109,
-    SBK_QSSLERROR_IDX                                        = 108,
-    SBK_QSSLKEY_IDX                                          = 110,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 111,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 114,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 113,
-    SBK_QSSLSOCKET_IDX                                       = 112,
-    SBK_QTCPSERVER_IDX                                       = 115,
-    SBK_QTCPSOCKET_IDX                                       = 116,
-    SBK_QUDPSOCKET_IDX                                       = 117,
+    SBK_QSSL_ALERTLEVEL_IDX                                  = 89,
+    SBK_QSSL_ALERTTYPE_IDX                                   = 90,
+    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 93,
+    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 98,
+    SBK_QtNetworkQSSL_IDX                                    = 88,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 101,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 100,
+    SBK_QSSLCERTIFICATE_IDX                                  = 99,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 102,
+    SBK_QSSLCIPHER_IDX                                       = 103,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 105,
+    SBK_QSSLCONFIGURATION_IDX                                = 104,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 107,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 106,
+    SBK_QSSLELLIPTICCURVE_IDX                                = 108,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 110,
+    SBK_QSSLERROR_IDX                                        = 109,
+    SBK_QSSLKEY_IDX                                          = 111,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 112,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 115,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 114,
+    SBK_QSSLSOCKET_IDX                                       = 113,
+    SBK_QTCPSERVER_IDX                                       = 116,
+    SBK_QTCPSOCKET_IDX                                       = 117,
+    SBK_QUDPSOCKET_IDX                                       = 118,
     SBK_QDTLSERROR_IDX                                       = 21,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 83,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 85,
-    SBK_QtNetwork_IDX_COUNT                                  = 118
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 84,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 86,
+    SBK_QtNetwork_IDX_COUNT                                  = 119
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtNetworkTypes;
@@ -239,39 +244,40 @@ extern SbkConverter **SbkPySide6_QtNetworkTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 0, // QList<QSslCertificate >
-    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
-    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 2, // QMap<QByteArray,QVariant >
-    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 3, // QList<QSslCipher >
-    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 4, // QList<QSslEllipticCurve >
-    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 5, // QList<QNetworkProxy >
-    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 6, // QList<QNetworkAddressEntry >
-    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 7, // QList<QHostAddress >
-    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 8, // QList<QNetworkInterface >
-    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 9, // QHash<QNetworkRequest::Attribute,QVariant >
-    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 10, // std::pair<QByteArray,QByteArray >
-    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 11, // QList<std::pair< QByteArray,QByteArray > >
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 12, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // QList<QObject* >
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 14, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 15, // QList<QHstsPolicy >
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 16, // QList<QSslError >
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 17, // QList<QDnsDomainNameRecord >
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 18, // QList<QDnsHostAddressRecord >
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 19, // QList<QDnsMailExchangeRecord >
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 20, // QList<QDnsServiceRecord >
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 21, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 22, // QPair<QHostAddress,int >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 23, // QList<QString >
-    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 24, // QList<QSsl::ImplementedClass >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 25, // QList<QOcspResponse >
-    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 26, // QList<QSsl::SupportedFeature >
-    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 27, // QList<QSsl::SslProtocol >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 28, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 29, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 30, // QList<QVariant >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 31, // QMap<QString,QVariant >
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 32
+    SBK_QTNETWORK_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 1, // QList<QSslCertificate >
+    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
+    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 3, // QMap<QByteArray,QVariant >
+    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 4, // QList<QSslCipher >
+    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 5, // QList<QSslEllipticCurve >
+    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 6, // QList<QNetworkProxy >
+    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 7, // QList<QNetworkAddressEntry >
+    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 8, // QList<QHostAddress >
+    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 9, // QList<QNetworkInterface >
+    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 10, // QHash<QNetworkRequest::Attribute,QVariant >
+    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 11, // std::pair<QByteArray,QByteArray >
+    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 12, // QList<std::pair< QByteArray,QByteArray > >
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 13, // QHash<QString,QVariant >
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 14, // QList<QObject* >
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 15, // QList<QNetworkCookie >
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 16, // QList<QHstsPolicy >
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 17, // QList<QSslError >
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 18, // QList<QDnsDomainNameRecord >
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 19, // QList<QDnsHostAddressRecord >
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 20, // QList<QDnsMailExchangeRecord >
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 21, // QList<QDnsServiceRecord >
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 22, // QList<QDnsTextRecord >
+    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 23, // QPair<QHostAddress,int >
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 24, // QList<QString >
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 25, // QList<QSsl::ImplementedClass >
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 26, // QList<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 27, // QList<QSsl::SupportedFeature >
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 28, // QList<QSsl::SslProtocol >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 29, // QList<QSslCertificateExtension >
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 30, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 31, // QList<QVariant >
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 32, // QMap<QString,QVariant >
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 33
 };
 // Macros for type check
 
@@ -341,6 +347,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkCookieJar >() { return reinte
 template<> inline PyTypeObject *SbkType< ::QNetworkDatagram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKDATAGRAM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkDiskCache >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKDISKCACHE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Reachability >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_REACHABILITY_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkInformation::TransportMedium >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_TRANSPORTMEDIUM_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Feature >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_FEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInformation::Feature> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_IDX]); }
