@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -61,7 +61,6 @@
 #include <QtNetworkAuth/qabstractoauthreplyhandler.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -76,6 +75,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -106,14 +110,15 @@ extern SbkConverter **SbkPySide6_QtNetworkAuthTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORKAUTH_QMAP_QSTRING_QVARIANT_IDX              = 0, // QMap<QString,QVariant >
-    SBK_QTNETWORKAUTH_QLIST_QOBJECTPTR_IDX                   = 1, // QList<QObject* >
-    SBK_QTNETWORKAUTH_QLIST_QBYTEARRAY_IDX                   = 2, // QList<QByteArray >
-    SBK_QTNETWORKAUTH_QMULTIMAP_QSTRING_QVARIANT_IDX         = 3, // QMultiMap<QString,QVariant >
-    SBK_QTNETWORKAUTH_QPAIR_QSTRING_QSTRING_IDX              = 4, // QPair<QString,QString >
-    SBK_QTNETWORKAUTH_QLIST_QSTRING_IDX                      = 5, // QList<QString >
-    SBK_QTNETWORKAUTH_QLIST_QVARIANT_IDX                     = 6, // QList<QVariant >
-    SBK_QtNetworkAuth_CONVERTERS_IDX_COUNT                   = 7
+    SBK_QTNETWORKAUTH_QLIST_INT_IDX                          = 0, // QList<int >
+    SBK_QTNETWORKAUTH_QMAP_QSTRING_QVARIANT_IDX              = 1, // QMap<QString,QVariant >
+    SBK_QTNETWORKAUTH_QLIST_QOBJECTPTR_IDX                   = 2, // QList<QObject* >
+    SBK_QTNETWORKAUTH_QLIST_QBYTEARRAY_IDX                   = 3, // QList<QByteArray >
+    SBK_QTNETWORKAUTH_QMULTIMAP_QSTRING_QVARIANT_IDX         = 4, // QMultiMap<QString,QVariant >
+    SBK_QTNETWORKAUTH_QPAIR_QSTRING_QSTRING_IDX              = 5, // QPair<QString,QString >
+    SBK_QTNETWORKAUTH_QLIST_QSTRING_IDX                      = 6, // QList<QString >
+    SBK_QTNETWORKAUTH_QLIST_QVARIANT_IDX                     = 7, // QList<QVariant >
+    SBK_QtNetworkAuth_CONVERTERS_IDX_COUNT                   = 8
 };
 // Macros for type check
 
