@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -55,7 +55,6 @@
 #include <QtOpenGLWidgets/qopenglwidget.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -70,6 +69,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -88,11 +92,12 @@ extern SbkConverter **SbkPySide6_QtOpenGLWidgetsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTOPENGLWIDGETS_QLIST_QACTIONPTR_IDX                 = 0, // QList<QAction* >
-    SBK_QTOPENGLWIDGETS_QLIST_QVARIANT_IDX                   = 1, // QList<QVariant >
-    SBK_QTOPENGLWIDGETS_QLIST_QSTRING_IDX                    = 2, // QList<QString >
-    SBK_QTOPENGLWIDGETS_QMAP_QSTRING_QVARIANT_IDX            = 3, // QMap<QString,QVariant >
-    SBK_QtOpenGLWidgets_CONVERTERS_IDX_COUNT                 = 4
+    SBK_QTOPENGLWIDGETS_QLIST_INT_IDX                        = 0, // QList<int >
+    SBK_QTOPENGLWIDGETS_QLIST_QACTIONPTR_IDX                 = 1, // QList<QAction* >
+    SBK_QTOPENGLWIDGETS_QLIST_QVARIANT_IDX                   = 2, // QList<QVariant >
+    SBK_QTOPENGLWIDGETS_QLIST_QSTRING_IDX                    = 3, // QList<QString >
+    SBK_QTOPENGLWIDGETS_QMAP_QSTRING_QVARIANT_IDX            = 4, // QMap<QString,QVariant >
+    SBK_QtOpenGLWidgets_CONVERTERS_IDX_COUNT                 = 5
 };
 // Macros for type check
 
