@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -50,25 +50,24 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
+#include <QtPositioning/qnmeapositioninfosource.h>
 #include <QtPositioning/qgeocoordinate.h>
 #include <QtPositioning/qgeopath.h>
+#include <QtPositioning/qgeoaddress.h>
+#include <QtPositioning/qgeopositioninfosource.h>
 #include <QtPositioning/qgeopolygon.h>
 #include <QtPositioning/qgeoareamonitorsource.h>
+#include <QtPositioning/qgeopositioninfosourcefactory.h>
 #include <QtPositioning/qgeolocation.h>
 #include <QtPositioning/qgeosatelliteinfosource.h>
 #include <QtPositioning/qgeosatelliteinfo.h>
 #include <QtPositioning/qgeoareamonitorinfo.h>
-#include <QtPositioning/qgeorectangle.h>
-#include <QtPositioning/qgeopositioninfo.h>
-#include <QtPositioning/qgeoshape.h>
-#include <QtPositioning/qnmeapositioninfosource.h>
-#include <QtPositioning/qgeoaddress.h>
-#include <QtPositioning/qgeopositioninfosource.h>
-#include <QtPositioning/qgeopositioninfosourcefactory.h>
 #include <QtPositioning/qgeocircle.h>
+#include <QtPositioning/qgeopositioninfo.h>
+#include <QtPositioning/qgeorectangle.h>
+#include <QtPositioning/qgeoshape.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -83,6 +82,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -129,15 +133,16 @@ extern SbkConverter **SbkPySide6_QtPositioningTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTPOSITIONING_QLIST_QGEOCOORDINATE_IDX               = 0, // QList<QGeoCoordinate >
-    SBK_QTPOSITIONING_QMAP_QSTRING_QVARIANT_IDX              = 1, // QMap<QString,QVariant >
-    SBK_QTPOSITIONING_QLIST_QVARIANT_IDX                     = 2, // QList<QVariant >
-    SBK_QTPOSITIONING_QLIST_QOBJECTPTR_IDX                   = 3, // QList<QObject* >
-    SBK_QTPOSITIONING_QLIST_QBYTEARRAY_IDX                   = 4, // QList<QByteArray >
-    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 5, // QList<QGeoSatelliteInfo >
-    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 6, // QList<QGeoAreaMonitorInfo >
-    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 7, // QList<QString >
-    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 8
+    SBK_QTPOSITIONING_QLIST_INT_IDX                          = 0, // QList<int >
+    SBK_QTPOSITIONING_QLIST_QGEOCOORDINATE_IDX               = 1, // QList<QGeoCoordinate >
+    SBK_QTPOSITIONING_QMAP_QSTRING_QVARIANT_IDX              = 2, // QMap<QString,QVariant >
+    SBK_QTPOSITIONING_QLIST_QVARIANT_IDX                     = 3, // QList<QVariant >
+    SBK_QTPOSITIONING_QLIST_QOBJECTPTR_IDX                   = 4, // QList<QObject* >
+    SBK_QTPOSITIONING_QLIST_QBYTEARRAY_IDX                   = 5, // QList<QByteArray >
+    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 6, // QList<QGeoSatelliteInfo >
+    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 7, // QList<QGeoAreaMonitorInfo >
+    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 8, // QList<QString >
+    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 9
 };
 // Macros for type check
 
