@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -62,7 +62,6 @@
 #include <QtPrintSupport/qabstractprintdialog.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -77,6 +76,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -116,11 +120,11 @@ extern SbkConverter **SbkPySide6_QtPrintSupportTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTPRINTSUPPORT_QLIST_QPRINTERINFO_IDX                = 0, // QList<QPrinterInfo >
-    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_COLORMODE_IDX          = 1, // QList<QPrinter::ColorMode >
-    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX         = 2, // QList<QPrinter::DuplexMode >
-    SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                   = 3, // QList<QPageSize >
-    SBK_QTPRINTSUPPORT_QLIST_INT_IDX                         = 4, // QList<int >
+    SBK_QTPRINTSUPPORT_QLIST_INT_IDX                         = 0, // QList<int >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTERINFO_IDX                = 1, // QList<QPrinterInfo >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_COLORMODE_IDX          = 2, // QList<QPrinter::ColorMode >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX         = 3, // QList<QPrinter::DuplexMode >
+    SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                   = 4, // QList<QPageSize >
     SBK_QTPRINTSUPPORT_QLIST_QWIDGETPTR_IDX                  = 5, // QList<QWidget* >
     SBK_QTPRINTSUPPORT_QLIST_QACTIONPTR_IDX                  = 6, // QList<QAction* >
     SBK_QTPRINTSUPPORT_QLIST_QVARIANT_IDX                    = 7, // QList<QVariant >
