@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -51,19 +51,21 @@
 #include <pyside6_qtnetwork_python.h>
 
 // Bound library includes
-#include <QtQml/qqmlexpression.h>
+#include <QtQml/qqmlextensioninterface.h>
 #include <QtQml/qqmlengine.h>
+#include <qpyqmlpropertyvaluesource.h>
 #include <QtQml/qjsprimitivevalue.h>
 #include <QtQml/qqml.h>
 #include <QtQml/qqmlcomponent.h>
 #include <QtQml/qqmldebug.h>
 #include <QtQml/qqmlapplicationengine.h>
+#include <qpyqmlparserstatus.h>
 #include <QtQml/qqmlnetworkaccessmanagerfactory.h>
-#include <QtQml/qqmlparserstatus.h>
 #include <QtQml/qjsvalue.h>
-#include <QtQml/qqmlscriptstring.h>
+#include <QtQml/qqmlparserstatus.h>
 #include <QtQml/qqmlabstracturlinterceptor.h>
 #include <QtQml/qqmlerror.h>
+#include <QtQml/qqmlscriptstring.h>
 #include <QtQml/qqmlextensionplugin.h>
 #include <QtQml/qjsvalueiterator.h>
 #include <QtQml/qqmllist.h>
@@ -76,10 +78,9 @@
 #include <QtQml/qqmlpropertyvaluesource.h>
 #include <QtQml/qqmlfileselector.h>
 #include <QtQml/qqmlcontext.h>
-#include <QtQml/qqmlextensioninterface.h>
+#include <QtQml/qqmlexpression.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -94,6 +95,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Begin code injection
 // Volatile Bool Ptr type definition for QQmlIncubationController::incubateWhile(std::atomic<bool> *, int)
@@ -122,44 +128,46 @@ enum : int {
     SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX                = 11,
     SBK_QJSVALUE_IDX                                         = 9,
     SBK_QJSVALUEITERATOR_IDX                                 = 13,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 16,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 15,
-    SBK_QQMLAPPLICATIONENGINE_IDX                            = 17,
-    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 19,
-    SBK_QQMLCOMPONENT_STATUS_IDX                             = 20,
-    SBK_QQMLCOMPONENT_IDX                                    = 18,
-    SBK_QQMLCONTEXT_IDX                                      = 21,
-    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 23,
-    SBK_QQMLDEBUGGINGENABLER_IDX                             = 22,
-    SBK_QQMLENGINE_IDX                                       = 24,
-    SBK_QQMLERROR_IDX                                        = 25,
-    SBK_QQMLEXPRESSION_IDX                                   = 26,
-    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 27,
-    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 28,
-    SBK_QQMLFILE_STATUS_IDX                                  = 30,
-    SBK_QQMLFILE_IDX                                         = 29,
-    SBK_QQMLFILESELECTOR_IDX                                 = 31,
-    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 34,
-    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 33,
+    SBK_QPYQMLPARSERSTATUS_IDX                               = 15,
+    SBK_QPYQMLPROPERTYVALUESOURCE_IDX                        = 16,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 18,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 17,
+    SBK_QQMLAPPLICATIONENGINE_IDX                            = 19,
+    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 21,
+    SBK_QQMLCOMPONENT_STATUS_IDX                             = 22,
+    SBK_QQMLCOMPONENT_IDX                                    = 20,
+    SBK_QQMLCONTEXT_IDX                                      = 23,
+    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 25,
+    SBK_QQMLDEBUGGINGENABLER_IDX                             = 24,
+    SBK_QQMLENGINE_IDX                                       = 26,
+    SBK_QQMLERROR_IDX                                        = 27,
+    SBK_QQMLEXPRESSION_IDX                                   = 28,
+    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 29,
+    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 30,
+    SBK_QQMLFILE_STATUS_IDX                                  = 32,
+    SBK_QQMLFILE_IDX                                         = 31,
+    SBK_QQMLFILESELECTOR_IDX                                 = 33,
+    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 36,
+    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 35,
     SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX                = 1,
-    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 32,
-    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 35,
-    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 37,
-    SBK_QQMLINCUBATOR_STATUS_IDX                             = 38,
-    SBK_QQMLINCUBATOR_IDX                                    = 36,
-    SBK_QQMLLISTREFERENCE_IDX                                = 39,
-    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 41,
-    SBK_QQMLPARSERSTATUS_IDX                                 = 42,
-    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 44,
-    SBK_QQMLPROPERTY_TYPE_IDX                                = 45,
-    SBK_QQMLPROPERTY_IDX                                     = 43,
-    SBK_QQMLPROPERTYMAP_IDX                                  = 46,
-    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 47,
-    SBK_QQMLSCRIPTSTRING_IDX                                 = 48,
-    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 49,
+    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 34,
+    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 37,
+    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 39,
+    SBK_QQMLINCUBATOR_STATUS_IDX                             = 40,
+    SBK_QQMLINCUBATOR_IDX                                    = 38,
+    SBK_QQMLLISTREFERENCE_IDX                                = 41,
+    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 43,
+    SBK_QQMLPARSERSTATUS_IDX                                 = 44,
+    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 46,
+    SBK_QQMLPROPERTY_TYPE_IDX                                = 47,
+    SBK_QQMLPROPERTY_IDX                                     = 45,
+    SBK_QQMLPROPERTYMAP_IDX                                  = 48,
+    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 49,
+    SBK_QQMLSCRIPTSTRING_IDX                                 = 50,
+    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 51,
     SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 14,
-    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 40,
-    SBK_QtQml_IDX_COUNT                                      = 51
+    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 42,
+    SBK_QtQml_IDX_COUNT                                      = 53
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtQmlTypes;
@@ -172,16 +180,17 @@ extern SbkConverter **SbkPySide6_QtQmlTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQML_QLIST_QQMLERROR_IDX                            = 0, // QList<QQmlError >
-    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 1, // QMap<QString,QVariant >
-    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 2, // QHash<QString,QVariant >
-    SBK_QTQML_QLIST_QJSVALUE_IDX                             = 3, // QList<QJSValue >
-    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 4, // QList<QObject* >
-    SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 5, // QList<QByteArray >
-    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 6, // QList<QQmlAbstractUrlInterceptor* >
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 7, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 8, // QList<QString >
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 9
+    SBK_QTQML_QLIST_INT_IDX                                  = 0, // QList<int >
+    SBK_QTQML_QLIST_QQMLERROR_IDX                            = 1, // QList<QQmlError >
+    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 2, // QMap<QString,QVariant >
+    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 3, // QHash<QString,QVariant >
+    SBK_QTQML_QLIST_QJSVALUE_IDX                             = 4, // QList<QJSValue >
+    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 5, // QList<QObject* >
+    SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 6, // QList<QByteArray >
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 7, // QList<QQmlAbstractUrlInterceptor* >
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 8, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 9, // QList<QString >
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 10
 };
 // Macros for type check
 
@@ -205,6 +214,8 @@ template<> inline PyTypeObject *SbkType< ::QJSValue::ErrorType >() { return SbkP
 template<> inline PyTypeObject *SbkType< ::QJSValue::ObjectConversionBehavior >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSVALUE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QJSValueIterator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSVALUEITERATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPyQmlParserStatus >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QPYQMLPARSERSTATUS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPyQmlPropertyValueSource >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QPYQMLPROPERTYVALUESOURCE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor::DataType >() { return SbkPySide6_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlApplicationEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLAPPLICATIONENGINE_IDX]); }
