@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -84,7 +84,6 @@
 #include <QtQuick/qsgtexture.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -99,6 +98,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -211,10 +215,10 @@ extern SbkConverter **SbkPySide6_QtQuickTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 0, // QList<QByteArray >
-    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 1, // QList<QObject* >
-    SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 2, // QList<QQuickItem* >
-    SBK_QTQUICK_QLIST_INT_IDX                                = 3, // QList<int >
+    SBK_QTQUICK_QLIST_INT_IDX                                = 0, // QList<int >
+    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 1, // QList<QByteArray >
+    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 2, // QList<QObject* >
+    SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 3, // QList<QQuickItem* >
     SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 4, // QList<QQmlError >
     SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // QMap<QString,QVariant >
     SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 6, // QList<QVariant >
