@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -59,7 +59,6 @@
 #include <QtQuickWidgets/qquickwidget.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -74,6 +73,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -93,12 +97,13 @@ extern SbkConverter **SbkPySide6_QtQuickWidgetsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQUICKWIDGETS_QLIST_QACTIONPTR_IDX                  = 0, // QList<QAction* >
-    SBK_QTQUICKWIDGETS_QLIST_QQMLERROR_IDX                   = 1, // QList<QQmlError >
-    SBK_QTQUICKWIDGETS_QLIST_QVARIANT_IDX                    = 2, // QList<QVariant >
-    SBK_QTQUICKWIDGETS_QLIST_QSTRING_IDX                     = 3, // QList<QString >
-    SBK_QTQUICKWIDGETS_QMAP_QSTRING_QVARIANT_IDX             = 4, // QMap<QString,QVariant >
-    SBK_QtQuickWidgets_CONVERTERS_IDX_COUNT                  = 5
+    SBK_QTQUICKWIDGETS_QLIST_INT_IDX                         = 0, // QList<int >
+    SBK_QTQUICKWIDGETS_QLIST_QACTIONPTR_IDX                  = 1, // QList<QAction* >
+    SBK_QTQUICKWIDGETS_QLIST_QQMLERROR_IDX                   = 2, // QList<QQmlError >
+    SBK_QTQUICKWIDGETS_QLIST_QVARIANT_IDX                    = 3, // QList<QVariant >
+    SBK_QTQUICKWIDGETS_QLIST_QSTRING_IDX                     = 4, // QList<QString >
+    SBK_QTQUICKWIDGETS_QMAP_QSTRING_QVARIANT_IDX             = 5, // QMap<QString,QVariant >
+    SBK_QtQuickWidgets_CONVERTERS_IDX_COUNT                  = 6
 };
 // Macros for type check
 
