@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -60,7 +60,6 @@
 #include <QtRemoteObjects/qtremoteobjectglobal.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -75,6 +74,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -108,18 +112,19 @@ extern SbkConverter **SbkPySide6_QtRemoteObjectsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTREMOTEOBJECTS_QLIST_QOBJECTPTR_IDX                 = 0, // QList<QObject* >
-    SBK_QTREMOTEOBJECTS_QLIST_QBYTEARRAY_IDX                 = 1, // QList<QByteArray >
-    SBK_QTREMOTEOBJECTS_QLIST_QVARIANT_IDX                   = 2, // QList<QVariant >
-    SBK_QTREMOTEOBJECTS_STD_PAIR_QSTRING_QREMOTEOBJECTSOURCELOCATIONINFO_IDX = 3, // std::pair<QString,QRemoteObjectSourceLocationInfo >
-    SBK_QTREMOTEOBJECTS_QHASH_QSTRING_QREMOTEOBJECTSOURCELOCATIONINFO_IDX = 4, // QHash<QString,QRemoteObjectSourceLocationInfo >
-    SBK_QTREMOTEOBJECTS_QLIST_INT_IDX                        = 5, // QList<int >
-    SBK_QTREMOTEOBJECTS_QMAP_INT_QVARIANT_IDX                = 6, // QMap<int,QVariant >
-    SBK_QTREMOTEOBJECTS_QLIST_QPERSISTENTMODELINDEX_IDX      = 7, // QList<QPersistentModelIndex >
-    SBK_QTREMOTEOBJECTS_QHASH_INT_QBYTEARRAY_IDX             = 8, // QHash<int,QByteArray >
-    SBK_QTREMOTEOBJECTS_QLIST_QSTRING_IDX                    = 9, // QList<QString >
-    SBK_QTREMOTEOBJECTS_QMAP_QSTRING_QVARIANT_IDX            = 10, // QMap<QString,QVariant >
-    SBK_QtRemoteObjects_CONVERTERS_IDX_COUNT                 = 11
+    SBK_QTREMOTEOBJECTS_QLIST_INT_IDX                        = 0, // QList<int >
+    SBK_QTREMOTEOBJECTS_QLIST_QOBJECTPTR_IDX                 = 1, // QList<QObject* >
+    SBK_QTREMOTEOBJECTS_QLIST_QBYTEARRAY_IDX                 = 2, // QList<QByteArray >
+    SBK_QTREMOTEOBJECTS_QLIST_QVARIANT_IDX                   = 3, // QList<QVariant >
+    SBK_QTREMOTEOBJECTS_STD_PAIR_QSTRING_QREMOTEOBJECTSOURCELOCATIONINFO_IDX = 4, // std::pair<QString,QRemoteObjectSourceLocationInfo >
+    SBK_QTREMOTEOBJECTS_QHASH_QSTRING_QREMOTEOBJECTSOURCELOCATIONINFO_IDX = 5, // QHash<QString,QRemoteObjectSourceLocationInfo >
+    SBK_QTREMOTEOBJECTS_QLIST_QMODELINDEX_IDX                = 6, // QList<QModelIndex >
+    SBK_QTREMOTEOBJECTS_QMAP_INT_QVARIANT_IDX                = 7, // QMap<int,QVariant >
+    SBK_QTREMOTEOBJECTS_QLIST_QPERSISTENTMODELINDEX_IDX      = 8, // QList<QPersistentModelIndex >
+    SBK_QTREMOTEOBJECTS_QHASH_INT_QBYTEARRAY_IDX             = 9, // QHash<int,QByteArray >
+    SBK_QTREMOTEOBJECTS_QLIST_QSTRING_IDX                    = 10, // QList<QString >
+    SBK_QTREMOTEOBJECTS_QMAP_QSTRING_QVARIANT_IDX            = 11, // QMap<QString,QVariant >
+    SBK_QtRemoteObjects_CONVERTERS_IDX_COUNT                 = 12
 };
 // Macros for type check
 
