@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -62,7 +62,6 @@
 #include <QtScxml/qscxmlnulldatamodel.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -77,6 +76,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -114,12 +118,12 @@ extern SbkConverter **SbkPySide6_QtScxmlTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSCXML_QLIST_QSCXMLERROR_IDX                        = 0, // QList<QScxmlError >
-    SBK_QTSCXML_QLIST_QOBJECTPTR_IDX                         = 1, // QList<QObject* >
-    SBK_QTSCXML_QLIST_QBYTEARRAY_IDX                         = 2, // QList<QByteArray >
-    SBK_QTSCXML_QMAP_QSTRING_QVARIANT_IDX                    = 3, // QMap<QString,QVariant >
-    SBK_QTSCXML_QLIST_QSCXMLINVOKABLESERVICEPTR_IDX          = 4, // QList<QScxmlInvokableService* >
-    SBK_QTSCXML_QLIST_INT_IDX                                = 5, // QList<int >
+    SBK_QTSCXML_QLIST_INT_IDX                                = 0, // QList<int >
+    SBK_QTSCXML_QLIST_QSCXMLERROR_IDX                        = 1, // QList<QScxmlError >
+    SBK_QTSCXML_QLIST_QOBJECTPTR_IDX                         = 2, // QList<QObject* >
+    SBK_QTSCXML_QLIST_QBYTEARRAY_IDX                         = 3, // QList<QByteArray >
+    SBK_QTSCXML_QMAP_QSTRING_QVARIANT_IDX                    = 4, // QMap<QString,QVariant >
+    SBK_QTSCXML_QLIST_QSCXMLINVOKABLESERVICEPTR_IDX          = 5, // QList<QScxmlInvokableService* >
     SBK_QTSCXML_QLIST_QSCXMLEXECUTABLECONTENT_PARAMETERINFO_IDX = 6, // QList<QScxmlExecutableContent::ParameterInfo >
     SBK_QTSCXML_QLIST_QVARIANT_IDX                           = 7, // QList<QVariant >
     SBK_QTSCXML_QLIST_QSTRING_IDX                            = 8, // QList<QString >
