@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -72,7 +72,6 @@
 #include <QtSensors/qsensorbackend.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -87,6 +86,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -166,16 +170,17 @@ extern SbkConverter **SbkPySide6_QtSensorsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSENSORS_QLIST_QOBJECTPTR_IDX                       = 0, // QList<QObject* >
-    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
-    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 2, // std::pair<int,int >
-    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 3, // QList<std::pair< int,int > >
-    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 4, // QList<QSensorFilter* >
-    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 5, // QList<qoutputrange >
-    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 6, // QList<QVariant >
-    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 7, // QList<QString >
-    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 8, // QMap<QString,QVariant >
-    SBK_QtSensors_CONVERTERS_IDX_COUNT                       = 9
+    SBK_QTSENSORS_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QTSENSORS_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
+    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
+    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 3, // std::pair<int,int >
+    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 4, // QList<std::pair< int,int > >
+    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 5, // QList<QSensorFilter* >
+    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 6, // QList<qoutputrange >
+    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 7, // QList<QVariant >
+    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 8, // QList<QString >
+    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 9, // QMap<QString,QVariant >
+    SBK_QtSensors_CONVERTERS_IDX_COUNT                       = 10
 };
 // Macros for type check
 
