@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -54,7 +54,6 @@
 #include <QtSerialPort/qserialport.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -69,6 +68,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -97,12 +101,13 @@ extern SbkConverter **SbkPySide6_QtSerialPortTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSERIALPORT_QLIST_QSERIALPORTINFO_IDX               = 0, // QList<QSerialPortInfo >
-    SBK_QTSERIALPORT_QLIST_QINT32_IDX                        = 1, // QList<qint32 >
-    SBK_QTSERIALPORT_QLIST_QVARIANT_IDX                      = 2, // QList<QVariant >
-    SBK_QTSERIALPORT_QLIST_QSTRING_IDX                       = 3, // QList<QString >
-    SBK_QTSERIALPORT_QMAP_QSTRING_QVARIANT_IDX               = 4, // QMap<QString,QVariant >
-    SBK_QtSerialPort_CONVERTERS_IDX_COUNT                    = 5
+    SBK_QTSERIALPORT_QLIST_INT_IDX                           = 0, // QList<int >
+    SBK_QTSERIALPORT_QLIST_QSERIALPORTINFO_IDX               = 1, // QList<QSerialPortInfo >
+    SBK_QTSERIALPORT_QLIST_QINT32_IDX                        = 2, // QList<qint32 >
+    SBK_QTSERIALPORT_QLIST_QVARIANT_IDX                      = 3, // QList<QVariant >
+    SBK_QTSERIALPORT_QLIST_QSTRING_IDX                       = 4, // QList<QString >
+    SBK_QTSERIALPORT_QMAP_QSTRING_QVARIANT_IDX               = 5, // QMap<QString,QVariant >
+    SBK_QtSerialPort_CONVERTERS_IDX_COUNT                    = 6
 };
 // Macros for type check
 
