@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2022 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt for Python.
@@ -55,11 +55,9 @@
 #include <QtUiTools/quiloader.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
@@ -71,6 +69,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -88,12 +91,13 @@ extern SbkConverter **SbkPySide6_QtUiToolsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTUITOOLS_QLIST_QOBJECTPTR_IDX                       = 0, // QList<QObject* >
-    SBK_QTUITOOLS_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
-    SBK_QTUITOOLS_QLIST_QVARIANT_IDX                         = 2, // QList<QVariant >
-    SBK_QTUITOOLS_QLIST_QSTRING_IDX                          = 3, // QList<QString >
-    SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                  = 4, // QMap<QString,QVariant >
-    SBK_QtUiTools_CONVERTERS_IDX_COUNT                       = 5
+    SBK_QTUITOOLS_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QTUITOOLS_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
+    SBK_QTUITOOLS_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
+    SBK_QTUITOOLS_QLIST_QVARIANT_IDX                         = 3, // QList<QVariant >
+    SBK_QTUITOOLS_QLIST_QSTRING_IDX                          = 4, // QList<QString >
+    SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                  = 5, // QMap<QString,QVariant >
+    SBK_QtUiTools_CONVERTERS_IDX_COUNT                       = 6
 };
 // Macros for type check
 
