@@ -3,11 +3,12 @@ import sys
 from pathlib import Path
 from textwrap import dedent
 
+# __all__ is also corrected below.
 __all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
+    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.2.2"
-__version_info__ = (6, 2, 2, "", "")
+__version__ = "6.3.0"
+__version_info__ = (6, 3, 0, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -23,8 +24,11 @@ def _additional_dll_directories(package_dir):
     # is executed in the build directory. We need libpyside and Qt in addition.
     shiboken6 = Path(root).parent / 'shiboken6' / 'libshiboken'
     if not shiboken6.is_dir():
-        raise ImportError(shiboken6 + ' does not exist')
+        raise ImportError(str(shiboken6) + ' does not exist')
     result = [shiboken6, root / 'libpyside']
+    libpysideqml = root / 'libpysideqml'
+    if libpysideqml.is_dir():
+        result.append(libpysideqml)
     for path in os.environ.get('PATH').split(';'):
         if path:
              if (Path(path) / 'qmake.exe').exists():
@@ -52,7 +56,7 @@ def _setupQtDirectories():
 
     if sys.platform == 'win32' and sys.version_info[0] == 3 and sys.version_info[1] >= 8:
         for dir in _additional_dll_directories(pyside_package_dir):
-            os.add_dll_directory(dir)
+            os.add_dll_directory(os.fspath(dir))
 
     try:
         # PYSIDE-1497: we use the build dir or install dir or site-packages, whatever the path
@@ -108,4 +112,32 @@ def _setupQtDirectories():
             finally:
                 os.environ['PATH'] = path
 
+
+def _find_all_qt_modules():
+    # Since the wheel split, the __all__ variable cannot be computed statically,
+    # because we don't know all modules in advance.
+
+    # Instead, we look into the file system and quickly build a list of all
+    # existing .pyi files, because importing is not desired and also impossible during import.
+    # By using the initially created list, we can keep some order intact.
+    location = Path(__file__).resolve().parent
+
+    # Note: We should _not_ call this function while still building, but use the existing value!
+    in_build = location.parents[2].name == "build"
+    if in_build:
+        return __all__
+
+    files = os.listdir(location)
+    unordered = set(name[:-4] for name in files if name.startswith("Qt") and name.endswith(".pyi"))
+    ordered_part = __all__
+    result = []
+    for name in ordered_part:
+        if name in unordered:
+            result.append(name)
+            unordered.remove(name)
+    result.extend(unordered)
+    return result
+
+
+__all__ = _find_all_qt_modules()
 _setupQtDirectories()
