@@ -42,8 +42,9 @@
  ********************************************************************/
 
 // @snippet include-pyside
-#include <pyside.h>
+#include <pysideinit.h>
 #include <limits>
+#include "glue/core_snippets_p.h"
 // @snippet include-pyside
 
 // @snippet qsettings-value
@@ -52,8 +53,9 @@
 // This avoids that we are passing '0' as defaultValue.
 // defaultValue can also be passed as positional argument,
 // not only as keyword.
+// PySide-535: Allow for empty dict instead of nullptr in PyPy
 QVariant out;
-if (kwds || numArgs > 1) {
+if ((kwds && PyDict_Size(kwds) > 0) || numArgs > 1) {
     Py_BEGIN_ALLOW_THREADS
     out = %CPPSELF.value(%1, %2);
     Py_END_ALLOW_THREADS
@@ -65,7 +67,7 @@ if (kwds || numArgs > 1) {
 
 PyTypeObject *typeObj = reinterpret_cast<PyTypeObject*>(%PYARG_3);
 
-if (typeObj) {
+if (typeObj && !Shiboken::ObjectType::checkType(typeObj)) {
     if (typeObj == &PyList_Type) {
         QByteArray out_ba = out.toByteArray();
         if (!out_ba.isEmpty()) {
@@ -105,8 +107,14 @@ if (typeObj) {
             Py_INCREF(Py_False);
             %PYARG_0 = Py_False;
         }
+    } else {
+        // TODO: PyDict_Type and PyTuple_Type
+        PyErr_SetString(PyExc_TypeError,
+                        "Invalid type parameter.\n"
+                        "\tUse 'list', 'bytes', 'str', 'int', 'float', 'bool', "
+                        "or a Qt-derived type");
+        return nullptr;
     }
-    // TODO: PyDict_Type and PyTuple_Type
 }
 else {
     if (!out.isValid()) {
@@ -120,16 +128,17 @@ else {
 // @snippet qsettings-value
 
 // @snippet conversion-pytypeobject-qmetatype
-if (Shiboken::String::checkType(reinterpret_cast<PyTypeObject *>(%in)))
+auto *pyType = reinterpret_cast<PyTypeObject *&>(%in);
+if (Shiboken::String::checkType(pyType))
     %out = QMetaType(QMetaType::QString);
 else if (%in == reinterpret_cast<PyObject *>(&PyFloat_Type))
     %out = QMetaType(QMetaType::Double);
 else if (%in == reinterpret_cast<PyObject *>(&PyLong_Type))
     %out = QMetaType(QMetaType::Int);
 else if (Py_TYPE(%in) == SbkObjectType_TypeF())
-    %out = QMetaType::fromName(Shiboken::ObjectType::getOriginalName((SbkObjectType *)%in));
+    %out = QMetaType::fromName(Shiboken::ObjectType::getOriginalName(pyType));
 else
-    %out = QMetaType::fromName(reinterpret_cast<PyTypeObject *>(%in)->tp_name);
+    %out = QMetaType::fromName(pyType->tp_name);
 // @snippet conversion-pytypeobject-qmetatype
 
 // @snippet conversion-qmetatype-pytypeobject
@@ -140,91 +149,6 @@ return %out;
 // @snippet conversion-qmetatype-pytypeobject
 
 // @snippet qvariant-conversion
-static QMetaType QVariant_resolveMetaType(PyTypeObject *type)
-{
-    if (PyObject_TypeCheck(type, SbkObjectType_TypeF())) {
-        auto sbkType = reinterpret_cast<SbkObjectType *>(type);
-        const char *typeName = Shiboken::ObjectType::getOriginalName(sbkType);
-        if (!typeName)
-            return {};
-        const bool valueType = '*' != typeName[qstrlen(typeName) - 1];
-        // Do not convert user type of value
-        if (valueType && Shiboken::ObjectType::isUserType(type))
-            return {};
-        QMetaType metaType = QMetaType::fromName(typeName);
-        if (metaType.isValid())
-            return metaType;
-        // Do not resolve types to value type
-        if (valueType)
-            return {};
-        // Find in base types. First check tp_bases, and only after check tp_base, because
-        // tp_base does not always point to the first base class, but rather to the first
-        // that has added any python fields or slots to its object layout.
-        // See https://mail.python.org/pipermail/python-list/2009-January/520733.html
-        if (type->tp_bases) {
-            for (int i = 0, size = PyTuple_GET_SIZE(type->tp_bases); i < size; ++i) {
-                auto baseType = reinterpret_cast<PyTypeObject *>(PyTuple_GET_ITEM(type->tp_bases, i));
-                const QMetaType derived = QVariant_resolveMetaType(baseType);
-                if (derived.isValid())
-                    return derived;
-            }
-        } else if (type->tp_base) {
-            return QVariant_resolveMetaType(type->tp_base);
-        }
-    }
-    return {};
-}
-static QVariant QVariant_convertToValueList(PyObject *list)
-{
-    if (PySequence_Size(list) < 0) {
-         // clear the error if < 0 which means no length at all
-         PyErr_Clear();
-         return QVariant();
-    }
-
-    Shiboken::AutoDecRef element(PySequence_GetItem(list, 0));
-
-    const QMetaType metaType = QVariant_resolveMetaType(element.cast<PyTypeObject *>());
-    if (metaType.isValid()) {
-        QByteArray listTypeName("QList<");
-        listTypeName += metaType.name();
-        listTypeName += '>';
-        QMetaType metaType = QMetaType::fromName(listTypeName);
-        if (metaType.isValid()) {
-            Shiboken::Conversions::SpecificConverter converter(listTypeName);
-            if (converter) {
-                QVariant var(metaType);
-                converter.toCpp(list, &var);
-                return var;
-            }
-            qWarning() << "Type converter for :" << listTypeName << "not registered.";
-        }
-    }
-    return QVariant();
-}
-static bool QVariant_isStringList(PyObject *list)
-{
-    if (!PySequence_Check(list)) {
-        // If it is not a list or a derived list class
-        // we assume that will not be a String list neither.
-        return false;
-    }
-
-    if (PySequence_Size(list) < 0) {
-        // clear the error if < 0 which means no length at all
-        PyErr_Clear();
-        return false;
-    }
-
-    Shiboken::AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
-    const Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
-    for (Py_ssize_t i = 0; i < size; ++i) {
-        PyObject *item = PySequence_Fast_GET_ITEM(fast.object(), i);
-        if (!%CHECKTYPE[QString](item))
-            return false;
-    }
-    return true;
-}
 static QVariant QVariant_convertToVariantMap(PyObject *map)
 {
     Py_ssize_t pos = 0;
@@ -274,30 +198,6 @@ double _abs = qAbs(%1);
 %PYARG_0 = %CONVERTTOPYTHON[double](_abs);
 // @snippet qt-qabs
 
-// @snippet qt-postroutine
-namespace PySide {
-static QStack<PyObject *> globalPostRoutineFunctions;
-void globalPostRoutineCallback()
-{
-    Shiboken::GilState state;
-    for (auto *callback : globalPostRoutineFunctions) {
-        Shiboken::AutoDecRef result(PyObject_CallObject(callback, nullptr));
-        Py_DECREF(callback);
-    }
-    globalPostRoutineFunctions.clear();
-}
-void addPostRoutine(PyObject *callback)
-{
-    if (PyCallable_Check(callback)) {
-        globalPostRoutineFunctions << callback;
-        Py_INCREF(callback);
-    } else {
-        PyErr_SetString(PyExc_TypeError, "qAddPostRoutine: The argument must be a callable object.");
-    }
-}
-} // namespace
-// @snippet qt-postroutine
-
 // @snippet qt-addpostroutine
 PySide::addPostRoutine(%1);
 // @snippet qt-addpostroutine
@@ -310,269 +210,48 @@ qAddPostRoutine(PySide::globalPostRoutineCallback);
 QList<QByteArray> version = QByteArray(qVersion()).split('.');
 PyObject *pyQtVersion = PyTuple_New(3);
 for (int i = 0; i < 3; ++i)
-    PyTuple_SET_ITEM(pyQtVersion, i, PyInt_FromLong(version[i].toInt()));
+    PyTuple_SET_ITEM(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
 PyModule_AddObject(module, "__version_info__", pyQtVersion);
 PyModule_AddStringConstant(module, "__version__", qVersion());
 // @snippet qt-version
 
 // @snippet qobject-connect
-static bool isMethodDecorator(PyObject *method, bool is_pymethod, PyObject *self)
-{
-    Shiboken::AutoDecRef methodName(PyObject_GetAttr(method, Shiboken::PyMagicName::name()));
-    if (!PyObject_HasAttr(self, methodName))
-        return true;
-    Shiboken::AutoDecRef otherMethod(PyObject_GetAttr(self, methodName));
-
-    PyObject *function1, *function2;
-
-    // PYSIDE-1523: Each could be a compiled method or a normal method here, for the
-    // compiled ones we can use the attributes.
-    if (PyMethod_Check(otherMethod.object())) {
-        function1 = PyMethod_GET_FUNCTION(otherMethod.object());
-    } else {
-        function1 = PyObject_GetAttr(otherMethod.object(), Shiboken::PyName::im_func());
-        Py_DECREF(function1);
-        // Not retaining a reference inline with what PyMethod_GET_FUNCTION does.
-    }
-
-    if (is_pymethod) {
-        function2 = PyMethod_GET_FUNCTION(method);
-    } else {
-        function2 = PyObject_GetAttr(method, Shiboken::PyName::im_func());
-        Py_DECREF(function2);
-        // Not retaining a reference inline with what PyMethod_GET_FUNCTION does.
-    }
-
-    return function1 != function2;
-}
-
-static bool getReceiver(QObject *source,
-                        const char *signal,
-                        PyObject *callback,
-                        QObject **receiver,
-                        PyObject **self,
-                        QByteArray *callbackSig)
-{
-    bool forceGlobalReceiver = false;
-    if (PyMethod_Check(callback)) {
-        *self = PyMethod_GET_SELF(callback);
-        if (%CHECKTYPE[QObject *](*self))
-            *receiver = %CONVERTTOCPP[QObject *](*self);
-        forceGlobalReceiver = isMethodDecorator(callback, true, *self);
-    } else if (PyCFunction_Check(callback)) {
-        *self = PyCFunction_GET_SELF(callback);
-        if (*self && %CHECKTYPE[QObject *](*self))
-            *receiver = %CONVERTTOCPP[QObject *](*self);
-    } else if (PyObject_HasAttr(callback, Shiboken::PyName::im_func())
-               && PyObject_HasAttr(callback, Shiboken::PyName::im_self())) {
-        *self = PyObject_GetAttr(callback, Shiboken::PyName::im_self());
-        Py_DECREF(*self);
-
-        if (%CHECKTYPE[QObject *](*self))
-            *receiver = %CONVERTTOCPP[QObject *](*self);
-        forceGlobalReceiver = isMethodDecorator(callback, false, *self);
-    } else if (PyCallable_Check(callback)) {
-        // Ok, just a callable object
-        *receiver = nullptr;
-        *self = nullptr;
-    }
-
-    bool usingGlobalReceiver = !*receiver || forceGlobalReceiver;
-
-    // Check if this callback is a overwrite of a non-virtual Qt slot.
-    if (!usingGlobalReceiver && receiver && self) {
-        *callbackSig = PySide::Signal::getCallbackSignature(signal, *receiver, callback, usingGlobalReceiver).toLatin1();
-        const QMetaObject *metaObject = (*receiver)->metaObject();
-        int slotIndex = metaObject->indexOfSlot(callbackSig->constData());
-        if (slotIndex != -1 && slotIndex < metaObject->methodOffset() && PyMethod_Check(callback))
-            usingGlobalReceiver = true;
-    }
-
-    const auto receiverThread = *receiver ? (*receiver)->thread() : nullptr;
-
-    if (usingGlobalReceiver) {
-        PySide::SignalManager &signalManager = PySide::SignalManager::instance();
-        *receiver = signalManager.globalReceiver(source, callback);
-        // PYSIDE-1354: Move the global receiver to the original receivers's thread
-        // so that autoconnections work correctly.
-        if (receiverThread && receiverThread != (*receiver)->thread())
-            (*receiver)->moveToThread(receiverThread);
-        *callbackSig = PySide::Signal::getCallbackSignature(signal, *receiver, callback, usingGlobalReceiver).toLatin1();
-    }
-
-    return usingGlobalReceiver;
-}
-
-static bool qobjectConnect(QObject *source, const char *signal, QObject *receiver, const char *slot, Qt::ConnectionType type)
-{
-    if (!signal || !slot)
-        return false;
-
-    if (!PySide::Signal::checkQtSignal(signal))
-        return false;
-    signal++;
-
-    if (!PySide::SignalManager::registerMetaMethod(source, signal, QMetaMethod::Signal))
-        return false;
-
-    bool isSignal = PySide::Signal::isQtSignal(slot);
-    slot++;
-    PySide::SignalManager::registerMetaMethod(receiver, slot, isSignal ? QMetaMethod::Signal : QMetaMethod::Slot);
-    bool connection;
-    connection = QObject::connect(source, signal - 1, receiver, slot - 1, type);
-    return connection;
-}
-
-static bool qobjectConnect(QObject *source, QMetaMethod signal, QObject *receiver, QMetaMethod slot, Qt::ConnectionType type)
-{
-   return qobjectConnect(source, signal.methodSignature(), receiver, slot.methodSignature(), type);
-}
-
-static bool qobjectConnectCallback(QObject *source, const char *signal, PyObject *callback, Qt::ConnectionType type)
-{
-    if (!signal || !PySide::Signal::checkQtSignal(signal))
-        return false;
-    signal++;
-
-    int signalIndex = PySide::SignalManager::registerMetaMethodGetIndex(source, signal, QMetaMethod::Signal);
-    if (signalIndex == -1)
-        return false;
-
-    PySide::SignalManager &signalManager = PySide::SignalManager::instance();
-
-    // Extract receiver from callback
-    QObject *receiver = nullptr;
-    PyObject *self = nullptr;
-    QByteArray callbackSig;
-    bool usingGlobalReceiver = getReceiver(source, signal, callback, &receiver, &self, &callbackSig);
-    if (receiver == nullptr && self == nullptr)
-        return false;
-
-    const QMetaObject *metaObject = receiver->metaObject();
-    const char *slot = callbackSig.constData();
-    int slotIndex = metaObject->indexOfSlot(slot);
-    QMetaMethod signalMethod = metaObject->method(signalIndex);
-
-    if (slotIndex == -1) {
-        if (!usingGlobalReceiver && self && !Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
-            qWarning("You can't add dynamic slots on an object originated from C++.");
-            if (usingGlobalReceiver)
-                signalManager.releaseGlobalReceiver(source, receiver);
-
-            return false;
-        }
-
-        if (usingGlobalReceiver)
-            slotIndex = signalManager.globalReceiverSlotIndex(receiver, slot);
-        else
-            slotIndex = PySide::SignalManager::registerMetaMethodGetIndex(receiver, slot, QMetaMethod::Slot);
-
-        if (slotIndex == -1) {
-            if (usingGlobalReceiver)
-                signalManager.releaseGlobalReceiver(source, receiver);
-
-            return false;
-        }
-    }
-    bool connection;
-    connection = QMetaObject::connect(source, signalIndex, receiver, slotIndex, type);
-    if (connection) {
-        if (usingGlobalReceiver)
-            signalManager.notifyGlobalReceiver(receiver);
-        #ifndef AVOID_PROTECTED_HACK
-            source->connectNotify(signalMethod); //Qt5: QMetaMethod instead of char *
-        #else
-            // Need to cast to QObjectWrapper * and call the public version of
-            // connectNotify when avoiding the protected hack.
-            reinterpret_cast<QObjectWrapper *>(source)->connectNotify(signalMethod); //Qt5: QMetaMethod instead of char *
-        #endif
-
-        return connection;
-    }
-
-    if (usingGlobalReceiver)
-        signalManager.releaseGlobalReceiver(source, receiver);
-
-    return false;
-}
-
-
-static bool qobjectDisconnectCallback(QObject *source, const char *signal, PyObject *callback)
-{
-    if (!PySide::Signal::checkQtSignal(signal))
-        return false;
-
-    PySide::SignalManager &signalManager = PySide::SignalManager::instance();
-
-    // Extract receiver from callback
-    QObject *receiver = nullptr;
-    PyObject *self = nullptr;
-    QByteArray callbackSig;
-    QMetaMethod slotMethod;
-    bool usingGlobalReceiver = getReceiver(nullptr, signal, callback, &receiver, &self, &callbackSig);
-    if (receiver == nullptr && self == nullptr)
-        return false;
-
-    const QMetaObject *metaObject = receiver->metaObject();
-    int signalIndex = source->metaObject()->indexOfSignal(++signal);
-    int slotIndex = -1;
-
-    slotIndex = metaObject->indexOfSlot(callbackSig);
-    slotMethod = metaObject->method(slotIndex);
-
-    bool disconnected;
-    disconnected = QMetaObject::disconnectOne(source, signalIndex, receiver, slotIndex);
-
-    if (disconnected) {
-        if (usingGlobalReceiver)
-            signalManager.releaseGlobalReceiver(source, receiver);
-
-        #ifndef AVOID_PROTECTED_HACK
-            source->disconnectNotify(slotMethod); //Qt5: QMetaMethod instead of char *
-        #else
-            // Need to cast to QObjectWrapper * and call the public version of
-            // connectNotify when avoiding the protected hack.
-            reinterpret_cast<QObjectWrapper *>(source)->disconnectNotify(slotMethod); //Qt5: QMetaMethod instead of char *
-        #endif
-        return true;
-    }
-    return false;
-}
+#include <qobjectconnect.h>
 // @snippet qobject-connect
 
 // @snippet qobject-connect-1
 // %FUNCTION_NAME() - disable generation of function call.
-bool %0 = qobjectConnect(%1, %2, %CPPSELF, %3, %4);
-%PYARG_0 = %CONVERTTOPYTHON[bool](%0);
+%RETURN_TYPE %0 = PySide::qobjectConnect(%1, %2, %CPPSELF, %3, %4);
+%PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-1
 
 // @snippet qobject-connect-2
 // %FUNCTION_NAME() - disable generation of function call.
-bool %0 = qobjectConnect(%1, %2, %3, %4, %5);
-%PYARG_0 = %CONVERTTOPYTHON[bool](%0);
+%RETURN_TYPE %0 = PySide::qobjectConnect(%1, %2, %3, %4, %5);
+%PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-2
 
 // @snippet qobject-connect-3
 // %FUNCTION_NAME() - disable generation of function call.
-bool %0 = qobjectConnect(%1, %2, %3, %4, %5);
-%PYARG_0 = %CONVERTTOPYTHON[bool](%0);
+%RETURN_TYPE %0 = PySide::qobjectConnect(%1, %2, %3, %4, %5);
+%PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-3
 
 // @snippet qobject-connect-4
 // %FUNCTION_NAME() - disable generation of function call.
-%RETURN_TYPE %0 = qobjectConnectCallback(%1, %2, %PYARG_3, %4);
+%RETURN_TYPE %0 = PySide::qobjectConnectCallback(%1, %2, %PYARG_3, %4);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-4
 
 // @snippet qobject-connect-5
 // %FUNCTION_NAME() - disable generation of function call.
-%RETURN_TYPE %0 = qobjectConnectCallback(%CPPSELF, %1, %PYARG_2, %3);
+%RETURN_TYPE %0 = PySide::qobjectConnectCallback(%CPPSELF, %1, %PYARG_2, %3);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-5
 
 // @snippet qobject-connect-6
 // %FUNCTION_NAME() - disable generation of function call.
-%RETURN_TYPE %0 = qobjectConnect(%CPPSELF, %1, %2, %3, %4);
+%RETURN_TYPE %0 = PySide::qobjectConnect(%CPPSELF, %1, %2, %3, %4);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-connect-6
 
@@ -583,13 +262,13 @@ bool %0 = qobjectConnect(%1, %2, %3, %4, %5);
 
 // @snippet qobject-disconnect-1
 // %FUNCTION_NAME() - disable generation of function call.
-%RETURN_TYPE %0 = qobjectDisconnectCallback(%CPPSELF, %1, %2);
+%RETURN_TYPE %0 = PySide::qobjectDisconnectCallback(%CPPSELF, %1, %2);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-disconnect-1
 
 // @snippet qobject-disconnect-2
 // %FUNCTION_NAME() - disable generation of function call.
-%RETURN_TYPE %0 = qobjectDisconnectCallback(%1, %2, %3);
+%RETURN_TYPE %0 = PySide::qobjectDisconnectCallback(%1, %2, %3);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-disconnect-2
 
@@ -641,8 +320,8 @@ static void msgHandlerCallback(QtMsgType type, const QMessageLogContext &ctx, co
     PyTuple_SET_ITEM(arglist, 0, %CONVERTTOPYTHON[QtMsgType](type));
     PyTuple_SET_ITEM(arglist, 1, %CONVERTTOPYTHON[QMessageLogContext &](ctx));
     QByteArray array = msg.toUtf8();  // Python handler requires UTF-8
-    char *data = array.data();
-    PyTuple_SET_ITEM(arglist, 2, %CONVERTTOPYTHON[char *](data));
+    const char *data = array.constData();
+    PyTuple_SET_ITEM(arglist, 2, %CONVERTTOPYTHON[const char *](data));
     Shiboken::AutoDecRef ret(PyObject_CallObject(qtmsghandler, arglist));
 }
 static void QtCoreModuleExit()
@@ -792,6 +471,11 @@ Py_XDECREF(result);
 return !result ? -1 : 0;
 // @snippet qbitarray-setitem
 
+// @snippet default-enter
+Py_INCREF(%PYSELF);
+pyResult = %PYSELF;
+// @snippet default-enter
+
 // @snippet qsignalblocker-unblock
 %CPPSELF.unblock();
 // @snippet qsignalblocker-unblock
@@ -814,78 +498,22 @@ qRegisterMetaType<QList<int> >("QList<int>");
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-metaobject
 
-// @snippet qobject-findchild-1
-static QObject *_findChildHelper(const QObject *parent, const QString &name,
-                                 PyTypeObject *desiredType,
-                                 Qt::FindChildOptions options)
-{
-    for (auto *child : parent->children()) {
-        Shiboken::AutoDecRef pyChild(%CONVERTTOPYTHON[QObject *](child));
-        if (PyType_IsSubtype(Py_TYPE(pyChild), desiredType)
-            && (name.isNull() || name == child->objectName())) {
-            return child;
-        }
-    }
-
-    if (options.testFlag(Qt::FindChildrenRecursively)) {
-        for (auto *child : parent->children()) {
-            QObject *obj = _findChildHelper(child, name, desiredType, options);
-            if (obj)
-                return obj;
-        }
-    }
-    return nullptr;
-}
-
-static inline bool _findChildrenComparator(const QObject *&child, const QRegularExpression &name)
-{
-    return name.match(child->objectName()).hasMatch();
-}
-
-static inline bool _findChildrenComparator(const QObject *&child, const QString &name)
-{
-    return name.isNull() || name == child->objectName();
-}
-
-template<typename T>
-static void _findChildrenHelper(const QObject *parent, const T& name, PyTypeObject *desiredType,
-                                Qt::FindChildOptions options,
-                                PyObject *result)
-{
-    for (const auto *child : parent->children()) {
-        Shiboken::AutoDecRef pyChild(%CONVERTTOPYTHON[QObject *](child));
-        if (PyType_IsSubtype(Py_TYPE(pyChild), desiredType) && _findChildrenComparator(child, name))
-            PyList_Append(result, pyChild);
-        if (options.testFlag(Qt::FindChildrenRecursively))
-            _findChildrenHelper(child, name, desiredType, options, result);
-    }
-}
-// @snippet qobject-findchild-1
-
 // @snippet qobject-findchild-2
-QObject *child = _findChildHelper(%CPPSELF, %2, reinterpret_cast<PyTypeObject *>(%PYARG_1), %3);
+QObject *child = qObjectFindChild(%CPPSELF, %2, reinterpret_cast<PyTypeObject *>(%PYARG_1), %3);
 %PYARG_0 = %CONVERTTOPYTHON[QObject *](child);
 // @snippet qobject-findchild-2
 
 // @snippet qobject-findchildren
 %PYARG_0 = PyList_New(0);
-_findChildrenHelper(%CPPSELF, %2, reinterpret_cast<PyTypeObject *>(%PYARG_1), %3, %PYARG_0);
+qObjectFindChildren(%CPPSELF, %2, reinterpret_cast<PyTypeObject *>(%PYARG_1), %3,
+                    [%PYARG_0](QObject *child) {
+                        Shiboken::AutoDecRef pyChild(%CONVERTTOPYTHON[QObject *](child));
+                        PyList_Append(%PYARG_0, pyChild.object());
+                    });
 // @snippet qobject-findchildren
 
 // @snippet qobject-tr
-QString result;
-if (QCoreApplication::instance()) {
-    PyObject *klass = PyObject_GetAttr(%PYSELF, Shiboken::PyMagicName::class_());
-    PyObject *cname = PyObject_GetAttr(klass, Shiboken::PyMagicName::name());
-    result = QString(QCoreApplication::instance()->translate(Shiboken::String::toCString(cname),
-                                                        /*   %1, %2, QCoreApplication::CodecForTr, %3)); */
-                                                             %1, %2, %3));
-
-    Py_DECREF(klass);
-    Py_DECREF(cname);
-} else {
-    result = QString(QString::fromLatin1(%1));
-}
+const QString result = qObjectTr(reinterpret_cast<PyTypeObject *>(%PYSELF), %1, %2, %3);
 %PYARG_0 = %CONVERTTOPYTHON[QString](result);
 // @snippet qobject-tr
 
@@ -900,8 +528,7 @@ if (ret > 0 && ((strcmp(%1, SIGNAL(destroyed())) == 0) || (strcmp(%1, SIGNAL(des
 
 // @snippet qbytearray-mgetitem
 if (PyIndex_Check(_key)) {
-    Py_ssize_t _i;
-    _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
+    const Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
     if (_i < 0 || _i >= %CPPSELF.size()) {
         PyErr_SetString(PyExc_IndexError, "index out of bounds");
         return 0;
@@ -912,27 +539,23 @@ if (PyIndex_Check(_key)) {
         return PyBytes_FromStringAndSize(res, 1);
     }
 } else if (PySlice_Check(_key)) {
-    Py_ssize_t start, stop, step, slicelength, cur;
-    if (PySlice_GetIndicesEx(_key, %CPPSELF.count(), &start, &stop, &step, &slicelength) < 0) {
+    Py_ssize_t start, stop, step, slicelength;
+    if (PySlice_GetIndicesEx(_key, %CPPSELF.size(), &start, &stop, &step, &slicelength) < 0)
         return nullptr;
-    }
 
     QByteArray ba;
     if (slicelength <= 0) {
         return %CONVERTTOPYTHON[QByteArray](ba);
     } else if (step == 1) {
-        Py_ssize_t max = %CPPSELF.count();
+        Py_ssize_t max = %CPPSELF.size();
         start = qBound(Py_ssize_t(0), start, max);
         stop = qBound(Py_ssize_t(0), stop, max);
-        QByteArray ba;
         if (start < stop)
             ba = %CPPSELF.mid(start, stop - start);
         return %CONVERTTOPYTHON[QByteArray](ba);
     } else {
-        QByteArray ba;
-        for (cur = start; slicelength > 0; cur += static_cast<size_t>(step), slicelength--) {
+        for (Py_ssize_t cur = start; slicelength > 0; cur += step, --slicelength)
             ba.append(%CPPSELF.at(cur));
-        }
         return %CONVERTTOPYTHON[QByteArray](ba);
     }
 } else {
@@ -950,7 +573,7 @@ if (PyIndex_Check(_key)) {
         return -1;
 
     if (_i < 0)
-        _i += %CPPSELF.count();
+        _i += %CPPSELF.size();
 
     if (_i < 0 || _i >= %CPPSELF.size()) {
         PyErr_SetString(PyExc_IndexError, "QByteArray index out of range");
@@ -968,7 +591,7 @@ if (PyIndex_Check(_key)) {
             PyErr_SetString(PyExc_ValueError, "bytearray must be of size 1");
             return -1;
         }
-    } else if (reinterpret_cast<PyTypeObject *>(Py_TYPE(_value)) == reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX])) {
+    } else if (Py_TYPE(_value) == reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX])) {
         if (PyObject_Length(_value) != 1) {
             PyErr_SetString(PyExc_ValueError, "QByteArray must be of size 1");
             return -1;
@@ -984,26 +607,24 @@ if (PyIndex_Check(_key)) {
     PyObject *result = Sbk_QByteArrayFunc_insert(self, args);
     Py_DECREF(args);
     Py_XDECREF(result);
-    return !result ? -1 : 0;
+    return result != nullptr ? 0: -1;
 } else if (PySlice_Check(_key)) {
-    Py_ssize_t start, stop, step, slicelength, value_length;
-    if (PySlice_GetIndicesEx(_key, %CPPSELF.count(), &start, &stop, &step, &slicelength) < 0) {
+    Py_ssize_t start, stop, step, slicelength;
+    if (PySlice_GetIndicesEx(_key, %CPPSELF.size(), &start, &stop, &step, &slicelength) < 0)
         return -1;
-    }
     // The parameter candidates are: bytes/str, bytearray, QByteArray itself.
-    // Not support iterable which contains ints between 0~255
+    // Not supported are iterables containing ints between 0~255
 
     // case 1: value is nullpre, means delete the items within the range
-    // case 2: step is 1, means shrink or expanse
+    // case 2: step is 1, means shrink or expand
     // case 3: step is not 1, then the number of slots have to equal the number of items in _value
-    QByteArray ba;
-    if (_value == nullptr || _value == Py_None) {
-        ba = QByteArray();
-        value_length = 0;
-    } else if (!(PyBytes_Check(_value) || PyByteArray_Check(_value) || reinterpret_cast<PyTypeObject *>(Py_TYPE(_value)) == reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX]))) {
-        PyErr_Format(PyExc_TypeError, "bytes, bytearray or QByteArray is required, not %.200s", Py_TYPE(_value)->tp_name);
-        return -1;
-    } else {
+    Py_ssize_t value_length = 0;
+    if (_value != nullptr && _value != Py_None) {
+        if (!(PyBytes_Check(_value) || PyByteArray_Check(_value)
+              || Py_TYPE(_value) == reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX]))) {
+               PyErr_Format(PyExc_TypeError, "bytes, bytearray or QByteArray is required, not %.200s", Py_TYPE(_value)->tp_name);
+               return -1;
+        }
         value_length = PyObject_Length(_value);
     }
 
@@ -1014,15 +635,16 @@ if (PyIndex_Check(_key)) {
     }
 
     if (step != 1) {
-        int i = start;
-        for (int j = 0; j < slicelength; j++) {
-            PyObject *item = PyObject_GetItem(_value, PyLong_FromLong(j));
+        Py_ssize_t i = start;
+        for (Py_ssize_t j = 0; j < slicelength; ++j) {
+            PyObject *item = PyObject_GetItem(_value, PyLong_FromSsize_t(j));
             QByteArray temp;
             if (PyLong_Check(item)) {
                 int overflow;
-                long ival = PyLong_AsLongAndOverflow(item, &overflow);
-                // Not suppose to bigger than 255 because only bytes, bytearray, QByteArray were accept
-                temp = QByteArray(reinterpret_cast<const char *>(&ival));
+                const long ival = PyLong_AsLongAndOverflow(item, &overflow);
+                // Not supposed to be bigger than 255 because only bytes,
+                // bytearray, QByteArray were accepted
+                temp.append(char(ival));
             } else {
                 temp = %CONVERTTOCPP[QByteArray](item);
             }
@@ -1032,7 +654,7 @@ if (PyIndex_Check(_key)) {
         }
         return 0;
     } else {
-        ba = %CONVERTTOCPP[QByteArray](_value);
+        QByteArray ba = %CONVERTTOCPP[QByteArray](_value);
         %CPPSELF.replace(start, slicelength, ba);
         return 0;
     }
@@ -1196,7 +818,7 @@ Py_DECREF(aux);
 // @snippet qbytearray-str
 
 // @snippet qbytearray-len
-return %CPPSELF.count();
+return %CPPSELF.size();
 // @snippet qbytearray-len
 
 // @snippet qbytearray-getitem
@@ -1240,6 +862,11 @@ QByteArray ba(1 + qsizetype(%2), char(0));
 %CPPSELF.%FUNCTION_NAME(Shiboken::String::toCString(%PYARG_1), Shiboken::String::len(%PYARG_1));
 // @snippet qcryptographichash-adddata
 
+// @snippet qmetaobject-repr
+const QByteArray repr = PySide::MetaObjectBuilder::formatMetaObject(%CPPSELF).toUtf8();
+%PYARG_0 = PyUnicode_FromString(repr.constData());
+// @snippet qmetaobject-repr
+
 // @snippet qsocketdescriptor
 #ifdef WIN32
 using DescriptorType = Qt::HANDLE;
@@ -1276,7 +903,7 @@ auto *ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(%PYARG_1, &si
 // %FUNCTION_NAME() - disable generation of c++ function call
 (void) %2; // remove warning about unused variable
 Shiboken::AutoDecRef emptyTuple(PyTuple_New(0));
-auto *timerType = reinterpret_cast<PyTypeObject *>(Shiboken::SbkType<QTimer>());
+auto *timerType = Shiboken::SbkType<QTimer>();
 auto *pyTimer = timerType->tp_new(Shiboken::SbkType<QTimer>(), emptyTuple, nullptr);
 timerType->tp_init(pyTimer, emptyTuple, nullptr);
 
@@ -1299,13 +926,13 @@ timer->start(%1);
 // @snippet qtimer-singleshot-2
 // %FUNCTION_NAME() - disable generation of c++ function call
 Shiboken::AutoDecRef emptyTuple(PyTuple_New(0));
-auto *timerType = reinterpret_cast<PyTypeObject *>(Shiboken::SbkType<QTimer>());
+auto *timerType = Shiboken::SbkType<QTimer>();
 auto *pyTimer = timerType->tp_new(Shiboken::SbkType<QTimer>(), emptyTuple, nullptr);
 timerType->tp_init(pyTimer, emptyTuple, nullptr);
 QTimer * timer = %CONVERTTOCPP[QTimer *](pyTimer);
 timer->setSingleShot(true);
 
-if (PyObject_TypeCheck(%2, PySideSignalInstanceTypeF())) {
+if (PyObject_TypeCheck(%2, PySideSignalInstance_TypeF())) {
     PySideSignalInstance *signalInstance = reinterpret_cast<PySideSignalInstance *>(%2);
     Shiboken::AutoDecRef signalSignature(Shiboken::String::fromFormat("2%s", PySide::Signal::getSignature(signalInstance)));
     Shiboken::AutoDecRef result(
@@ -1390,7 +1017,7 @@ if (result == -1) {
     Py_INCREF(Py_None);
     %PYARG_0 = Py_None;
 } else {
-    %PYARG_0 = PyBytes_FromStringAndSize(data.data(), result);
+    %PYARG_0 = PyBytes_FromStringAndSize(data.constData(), result);
 }
 // @snippet qdatastream-readrawdata
 
@@ -1509,11 +1136,11 @@ QString &res = *%0;
 // @snippet return-readData
 %RETURN_TYPE %0 = 0;
 if (PyBytes_Check(%PYARG_0)) {
-    %0 = PyBytes_GET_SIZE((PyObject *)%PYARG_0);
-    memcpy(%1, PyBytes_AS_STRING((PyObject *)%PYARG_0), %0);
-} else if (Shiboken::String::check(%PYARG_0)) {
-    %0 = Shiboken::String::len((PyObject *)%PYARG_0);
-    memcpy(%1, Shiboken::String::toCString((PyObject *)%PYARG_0), %0);
+    %0 = PyBytes_GET_SIZE(%PYARG_0.object());
+    memcpy(%1, PyBytes_AS_STRING(%PYARG_0.object()), %0);
+} else if (Shiboken::String::check(%PYARG_0.object())) {
+    %0 = Shiboken::String::len(%PYARG_0.object());
+    memcpy(%1, Shiboken::String::toCString(%PYARG_0.object()), %0);
 }
 // @snippet return-readData
 
@@ -1548,7 +1175,16 @@ Py_END_ALLOW_THREADS
     }
 }
 // @snippet qt-module-shutdown
-//
+
+// @snippet qthread_init_pypy
+#ifdef PYPY_VERSION
+// PYSIDE-535: PyPy 7.3.8 needs this call, which is actually a no-op in Python 3.9
+//             This function should be replaced by a `Py_Initialize` call, but
+//             that is still undefined. So we don't rely yet on any PyPy version.
+PyEval_InitThreads();
+#endif
+// @snippet qthread_init_pypy
+
 // @snippet qthread_exec_
 if (PyErr_WarnEx(PyExc_DeprecationWarning,
                  "'exec_' will be removed in the future. "
@@ -1629,10 +1265,6 @@ if (PyErr_WarnEx(PyExc_DeprecationWarning,
 %out = %OUTTYPE(%in == Py_True);
 // @snippet conversion-pybool
 
-// @snippet conversion-pylong
-%out = %OUTTYPE(PyLong_AsLong(%in));
-// @snippet conversion-pylong
-
 // @snippet conversion-pylong-quintptr
 #if QT_POINTER_SIZE == 8
 %out = %OUTTYPE(PyLong_AsUnsignedLongLong(%in));
@@ -1642,33 +1274,38 @@ if (PyErr_WarnEx(PyExc_DeprecationWarning,
 // @snippet conversion-pylong-quintptr
 
 // @snippet conversion-pyunicode
-#ifndef Py_LIMITED_API
-Py_UNICODE *unicode = PyUnicode_AS_UNICODE(%in);
-#  if defined(Py_UNICODE_WIDE)
-// cast as Py_UNICODE can be a different type
-#    if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-%out = QString::fromUcs4(reinterpret_cast<const char32_t *>(unicode));
-#    else
-%out = QString::fromUcs4(reinterpret_cast<const uint *>(unicode));
-#    endif // Qt 6
-#  else // Py_UNICODE_WIDE
-#    if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-%out = QString::fromUtf16(reinterpret_cast<const char16_t *>(unicode), PepUnicode_GetLength(%in));
-#    else
-%out = QString::fromUtf16(reinterpret_cast<const ushort *>(unicode), PepUnicode_GetLength(%in));
-#    endif // Qt 6
-# endif
-#else
-wchar_t *temp = PyUnicode_AsWideCharString(%in, nullptr);
-%out = QString::fromWCharArray(temp);
-PyMem_Free(temp);
-#endif
+void *data = _PepUnicode_DATA(%in);
+Py_ssize_t len = PyUnicode_GetLength(%in);
+switch (_PepUnicode_KIND(%in)) {
+    case PepUnicode_1BYTE_KIND:
+        %out = QString::fromLatin1(reinterpret_cast<const char *>(data));
+        break;
+    case PepUnicode_2BYTE_KIND:
+        %out = QString::fromUtf16(reinterpret_cast<const char16_t *>(data), len);
+        break;
+    case PepUnicode_4BYTE_KIND:
+        %out = QString::fromUcs4(reinterpret_cast<const char32_t *>(data), len);
+        break;
+}
 // @snippet conversion-pyunicode
 
 // @snippet conversion-pynone
 %out = %OUTTYPE();
 // @snippet conversion-pynone
 
+// @snippet qfile-path-1
+auto cppArg0 = PySide::pyPathToQString(%PYARG_1);
+// @snippet qfile-path-1
+
+// @snippet qfile-path-2
+auto cppArg1 = PySide::pyPathToQString(%PYARG_2);
+// @snippet qfile-path-2
+
+// @snippet qitemselection-add
+auto res = (*%CPPSELF) + cppArg0;
+%PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](res);
+// @snippet qitemselection-add
+
 // @snippet conversion-pystring-char
 char c = %CONVERTTOCPP[char](%in);
 %out = %OUTTYPE(c);
@@ -1737,11 +1374,6 @@ QJsonValue val = QJsonValue::fromVariant(dict);
 %out = val.toObject();
 // @snippet conversion-qjsonobject-pydict
 
-// @snippet conversion-qpair-pysequence
-%out.first = %CONVERTTOCPP[%OUTTYPE_0](PySequence_Fast_GET_ITEM(%in, 0));
-%out.second = %CONVERTTOCPP[%OUTTYPE_1](PySequence_Fast_GET_ITEM(%in, 1));
-// @snippet conversion-qpair-pysequence
-
 // @snippet conversion-qdate-pydate
 int day = PyDateTime_GET_DAY(%in);
 int month = PyDateTime_GET_MONTH(%in);
@@ -1809,6 +1441,11 @@ QByteArray ba = %in.toUtf8();
 return PyUnicode_FromStringAndSize(ba.constData(), ba.size());
 // @snippet return-pyunicode
 
+// @snippet return-pyunicode-from-qanystringview
+QByteArray ba = %in.toString().toUtf8();
+return PyUnicode_FromStringAndSize(ba.constData(), ba.size());
+// @snippet return-pyunicode-from-qanystringview
+
 // @snippet return-pyunicode-qchar
 auto c = wchar_t(%in.unicode());
 return PyUnicode_FromWideChar(&c, 1);
@@ -1862,13 +1499,6 @@ QVariant ret = val.toVariant();
 return %CONVERTTOPYTHON[QVariant](ret);
 // @snippet return-qjsonobject
 
-// @snippet return-qpair
-PyObject *%out = PyTuple_New(2);
-PyTuple_SET_ITEM(%out, 0, %CONVERTTOPYTHON[%INTYPE_0](%in.first));
-PyTuple_SET_ITEM(%out, 1, %CONVERTTOPYTHON[%INTYPE_1](%in.second));
-return %out;
-// @snippet return-qpair
-
 // @snippet qthread_pthread_cleanup
 #ifdef Q_OS_UNIX
 #  include <stdio.h>
@@ -1906,3 +1536,63 @@ Py_DECREF(oldResult);
 Py_DECREF(suffix);
 #endif
 // @snippet qlibraryinfo_build
+
+// @snippet qsharedmemory_data_readonly
+%PYARG_0 = Shiboken::Buffer::newObject(%CPPSELF.%FUNCTION_NAME(), %CPPSELF.size());
+// @snippet qsharedmemory_data_readonly
+
+// @snippet qsharedmemory_data_readwrite
+// FIXME: There is no way to tell whether QSharedMemory was attached read/write
+%PYARG_0 = Shiboken::Buffer::newObject(%CPPSELF.%FUNCTION_NAME(), %CPPSELF.size(),
+                                       Shiboken::Buffer::ReadWrite);
+// @snippet qsharedmemory_data_readwrite
+
+// @snippet std-function-void-lambda
+auto *callable = %PYARG_1;
+auto cppCallback = [callable]()
+{
+    Shiboken::GilState state;
+    Shiboken::AutoDecRef arglist(PyTuple_New(0));
+    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
+    Py_DECREF(callable);
+};
+// @snippet std-function-void-lambda
+
+// @snippet qthreadpool-start
+Py_INCREF(callable);
+%CPPSELF.%FUNCTION_NAME(cppCallback, %2);
+// @snippet qthreadpool-start
+
+// @snippet qthreadpool-trystart
+Py_INCREF(callable);
+%RETURN_TYPE %0 = %CPPSELF.%FUNCTION_NAME(cppCallback);
+%PYARG_0 = %CONVERTTOPYTHON[int](cppResult);
+// @snippet qthreadpool-trystart
+
+// @snippet repr-qevent
+QString result;
+QDebug(&result).nospace() << "<PySide6.QtCore.QEvent(" << %CPPSELF->type() << ")>";
+%PYARG_0 = Shiboken::String::fromCString(qPrintable(result));
+// @snippet repr-qevent
+
+// @snippet qmetaproperty_write_enum
+if (Shiboken::Enum::check(%PYARG_2)) {
+    int in = %CONVERTTOCPP[int](%PYARG_2);
+    cppArg1 = QVariant(in);
+}
+// @snippet qmetaproperty_write_enum
+
+// @snippet qdatastream-read-bytes
+QByteArray data;
+data.resize(%2);
+auto dataChar = data.data();
+cppSelf->readBytes(dataChar, %2);
+const char *constDataChar = dataChar;
+if (dataChar == nullptr) {
+    Py_INCREF(Py_None);
+    %PYARG_0 = Py_None;
+} else {
+    %PYARG_0 = PyBytes_FromStringAndSize(constDataChar, %2);
+}
+// @snippet qdatastream-read-bytes
+
